/* SPDX-FileCopyrightText: © 2022-2024 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef InstrIdType_Names_array_h_automatic
#define InstrIdType_Names_array_h_automatic

const char *RabInstrIdType_Names[] = {
    [RAB_INSTR_ID_TYPE_ALL_INVALID] = "ALL" "_" "INVALID",
    [RAB_INSTR_ID_TYPE_CPU_INVALID] = "CPU" "_" "INVALID",
    [RAB_INSTR_ID_TYPE_CPU_NORMAL] = "CPU" "_" "NORMAL",
    [RAB_INSTR_ID_TYPE_CPU_SPECIAL] = "CPU" "_" "SPECIAL",
    [RAB_INSTR_ID_TYPE_CPU_REGIMM] = "CPU" "_" "REGIMM",
    [RAB_INSTR_ID_TYPE_CPU_COP0] = "CPU" "_" "COP0",
    [RAB_INSTR_ID_TYPE_CPU_COP0_BC0] = "CPU" "_" "COP0_BC0",
    [RAB_INSTR_ID_TYPE_CPU_COP0_TLB] = "CPU" "_" "COP0_TLB",
    [RAB_INSTR_ID_TYPE_CPU_COP1] = "CPU" "_" "COP1",
    [RAB_INSTR_ID_TYPE_CPU_COP1_BC1] = "CPU" "_" "COP1_BC1",
    [RAB_INSTR_ID_TYPE_CPU_COP1_FPUS] = "CPU" "_" "COP1_FPUS",
    [RAB_INSTR_ID_TYPE_CPU_COP1_FPUD] = "CPU" "_" "COP1_FPUD",
    [RAB_INSTR_ID_TYPE_CPU_COP1_FPUW] = "CPU" "_" "COP1_FPUW",
    [RAB_INSTR_ID_TYPE_CPU_COP1_FPUL] = "CPU" "_" "COP1_FPUL",
    [RAB_INSTR_ID_TYPE_CPU_COP2] = "CPU" "_" "COP2",
    [RAB_INSTR_ID_TYPE_RSP_INVALID] = "RSP" "_" "INVALID",
    [RAB_INSTR_ID_TYPE_RSP_NORMAL] = "RSP" "_" "NORMAL",
    [RAB_INSTR_ID_TYPE_RSP_NORMAL_LWC2] = "RSP" "_" "NORMAL_LWC2",
    [RAB_INSTR_ID_TYPE_RSP_NORMAL_SWC2] = "RSP" "_" "NORMAL_SWC2",
    [RAB_INSTR_ID_TYPE_RSP_SPECIAL] = "RSP" "_" "SPECIAL",
    [RAB_INSTR_ID_TYPE_RSP_REGIMM] = "RSP" "_" "REGIMM",
    [RAB_INSTR_ID_TYPE_RSP_COP0] = "RSP" "_" "COP0",
    [RAB_INSTR_ID_TYPE_RSP_COP1] = "RSP" "_" "COP1",
    [RAB_INSTR_ID_TYPE_RSP_COP2] = "RSP" "_" "COP2",
    [RAB_INSTR_ID_TYPE_RSP_COP2_VU] = "RSP" "_" "COP2_VU",
    [RAB_INSTR_ID_TYPE_R3000GTE_INVALID] = "R3000GTE" "_" "INVALID",
    [RAB_INSTR_ID_TYPE_R3000GTE_NORMAL] = "R3000GTE" "_" "NORMAL",
    [RAB_INSTR_ID_TYPE_R3000GTE_SPECIAL] = "R3000GTE" "_" "SPECIAL",
    [RAB_INSTR_ID_TYPE_R3000GTE_REGIMM] = "R3000GTE" "_" "REGIMM",
    [RAB_INSTR_ID_TYPE_R3000GTE_COP0] = "R3000GTE" "_" "COP0",
    [RAB_INSTR_ID_TYPE_R3000GTE_COP1] = "R3000GTE" "_" "COP1",
    [RAB_INSTR_ID_TYPE_R3000GTE_COP2] = "R3000GTE" "_" "COP2",
    [RAB_INSTR_ID_TYPE_R3000GTE_COP2_GTE] = "R3000GTE" "_" "COP2_GTE",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_INVALID] = "R4000ALLEGREX" "_" "INVALID",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_NORMAL] = "R4000ALLEGREX" "_" "NORMAL",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_SPECIAL] = "R4000ALLEGREX" "_" "SPECIAL",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_SPECIAL_RS] = "R4000ALLEGREX" "_" "SPECIAL_RS",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_SPECIAL_SA] = "R4000ALLEGREX" "_" "SPECIAL_SA",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_REGIMM] = "R4000ALLEGREX" "_" "REGIMM",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_SPECIAL2] = "R4000ALLEGREX" "_" "SPECIAL2",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_SPECIAL3] = "R4000ALLEGREX" "_" "SPECIAL3",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_SPECIAL3_BSHFL] = "R4000ALLEGREX" "_" "SPECIAL3_BSHFL",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP0] = "R4000ALLEGREX" "_" "COP0",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP0_BC0] = "R4000ALLEGREX" "_" "COP0_BC0",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP0_TLB] = "R4000ALLEGREX" "_" "COP0_TLB",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP1] = "R4000ALLEGREX" "_" "COP1",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP1_BC1] = "R4000ALLEGREX" "_" "COP1_BC1",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP1_FPUS] = "R4000ALLEGREX" "_" "COP1_FPUS",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP1_FPUW] = "R4000ALLEGREX" "_" "COP1_FPUW",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP2] = "R4000ALLEGREX" "_" "COP2",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP2_BC2] = "R4000ALLEGREX" "_" "COP2_BC2",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP2_MFHC2] = "R4000ALLEGREX" "_" "COP2_MFHC2",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP2_MFHC2_P] = "R4000ALLEGREX" "_" "COP2_MFHC2_P",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP2_MFHC2_P_S] = "R4000ALLEGREX" "_" "COP2_MFHC2_P_S",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_COP2_MTHC2] = "R4000ALLEGREX" "_" "COP2_MTHC2",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU0] = "R4000ALLEGREX" "_" "VFPU0",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU1] = "R4000ALLEGREX" "_" "VFPU1",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU3] = "R4000ALLEGREX" "_" "VFPU3",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4] = "R4000ALLEGREX" "_" "VFPU4",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0] = "R4000ALLEGREX" "_" "VFPU4_FMT0",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_FMT0] = "R4000ALLEGREX" "_" "VFPU4_FMT0_FMT0",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_FMT2] = "R4000ALLEGREX" "_" "VFPU4_FMT0_FMT2",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_FMT3] = "R4000ALLEGREX" "_" "VFPU4_FMT0_FMT3",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_RND] = "R4000ALLEGREX" "_" "VFPU4_FMT0_RND",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_CVTFLT] = "R4000ALLEGREX" "_" "VFPU4_FMT0_CVTFLT",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_CVTINT] = "R4000ALLEGREX" "_" "VFPU4_FMT0_CVTINT",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_FMT8] = "R4000ALLEGREX" "_" "VFPU4_FMT0_FMT8",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_FMT9] = "R4000ALLEGREX" "_" "VFPU4_FMT0_FMT9",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_CONTROL] = "R4000ALLEGREX" "_" "VFPU4_FMT0_CONTROL",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_COLOR] = "R4000ALLEGREX" "_" "VFPU4_FMT0_COLOR",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT0_CST] = "R4000ALLEGREX" "_" "VFPU4_FMT0_CST",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT2] = "R4000ALLEGREX" "_" "VFPU4_FMT2",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU4_FMT2_CNDMOVE] = "R4000ALLEGREX" "_" "VFPU4_FMT2_CNDMOVE",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU5] = "R4000ALLEGREX" "_" "VFPU5",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU6] = "R4000ALLEGREX" "_" "VFPU6",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU6_FMT7] = "R4000ALLEGREX" "_" "VFPU6_FMT7",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU6_FMT7_FMT0] = "R4000ALLEGREX" "_" "VFPU6_FMT7_FMT0",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_VFPU7] = "R4000ALLEGREX" "_" "VFPU7",
    [RAB_INSTR_ID_TYPE_R4000ALLEGREX_QUADLR] = "R4000ALLEGREX" "_" "QUADLR",
    [RAB_INSTR_ID_TYPE_R5900_INVALID] = "R5900" "_" "INVALID",
    [RAB_INSTR_ID_TYPE_R5900_NORMAL] = "R5900" "_" "NORMAL",
    [RAB_INSTR_ID_TYPE_R5900_SPECIAL] = "R5900" "_" "SPECIAL",
    [RAB_INSTR_ID_TYPE_R5900_REGIMM] = "R5900" "_" "REGIMM",
    [RAB_INSTR_ID_TYPE_R5900_COP0] = "R5900" "_" "COP0",
    [RAB_INSTR_ID_TYPE_R5900_COP0_TLB] = "R5900" "_" "COP0_TLB",
    [RAB_INSTR_ID_TYPE_R5900_COP1] = "R5900" "_" "COP1",
    [RAB_INSTR_ID_TYPE_R5900_COP1_FPUS] = "R5900" "_" "COP1_FPUS",
    [RAB_INSTR_ID_TYPE_R5900_COP2] = "R5900" "_" "COP2",
    [RAB_INSTR_ID_TYPE_R5900_COP2_NOHIGHBIT] = "R5900" "_" "COP2_NOHIGHBIT",
    [RAB_INSTR_ID_TYPE_R5900_COP2_BC2] = "R5900" "_" "COP2_BC2",
    [RAB_INSTR_ID_TYPE_R5900_COP2_SPECIAL1] = "R5900" "_" "COP2_SPECIAL1",
    [RAB_INSTR_ID_TYPE_R5900_COP2_SPECIAL2] = "R5900" "_" "COP2_SPECIAL2",
    [RAB_INSTR_ID_TYPE_R5900_COP2_VIWR] = "R5900" "_" "COP2_VIWR",
    [RAB_INSTR_ID_TYPE_R5900_MMI] = "R5900" "_" "MMI",
    [RAB_INSTR_ID_TYPE_R5900_MMI_0] = "R5900" "_" "MMI_0",
    [RAB_INSTR_ID_TYPE_R5900_MMI_1] = "R5900" "_" "MMI_1",
    [RAB_INSTR_ID_TYPE_R5900_MMI_2] = "R5900" "_" "MMI_2",
    [RAB_INSTR_ID_TYPE_R5900_MMI_3] = "R5900" "_" "MMI_3",
    [RAB_INSTR_ID_TYPE_R5900_MMI_PMFHL] = "R5900" "_" "MMI_PMFHL",
    [RAB_INSTR_ID_TYPE_R5900_MMI_PMTHL] = "R5900" "_" "MMI_PMTHL",
    [RAB_INSTR_ID_TYPE_ALL_MAX] = "ALL" "_" "MAX",
};

#endif
