/* SPDX-FileCopyrightText: © 2022-2024 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef InstrId_Names_array_h_automatic
#define InstrId_Names_array_h_automatic

const char *RabbitizerInstrId_Names[] = {
    [RABBITIZER_INSTR_ID_cpu_INVALID] = "INVALID",
    [RABBITIZER_INSTR_ID_cpu_j] = "j",
    [RABBITIZER_INSTR_ID_cpu_jal] = "jal",
    [RABBITIZER_INSTR_ID_cpu_beq] = "beq",
    [RABBITIZER_INSTR_ID_cpu_bne] = "bne",
    [RABBITIZER_INSTR_ID_cpu_beql] = "beql",
    [RABBITIZER_INSTR_ID_cpu_bnel] = "bnel",
    [RABBITIZER_INSTR_ID_cpu_blez] = "blez",
    [RABBITIZER_INSTR_ID_cpu_blezl] = "blezl",
    [RABBITIZER_INSTR_ID_cpu_bgtz] = "bgtz",
    [RABBITIZER_INSTR_ID_cpu_bgtzl] = "bgtzl",
    [RABBITIZER_INSTR_ID_cpu_addi] = "addi",
    [RABBITIZER_INSTR_ID_cpu_addiu] = "addiu",
    [RABBITIZER_INSTR_ID_cpu_slti] = "slti",
    [RABBITIZER_INSTR_ID_cpu_sltiu] = "sltiu",
    [RABBITIZER_INSTR_ID_cpu_andi] = "andi",
    [RABBITIZER_INSTR_ID_cpu_ori] = "ori",
    [RABBITIZER_INSTR_ID_cpu_xori] = "xori",
    [RABBITIZER_INSTR_ID_cpu_daddi] = "daddi",
    [RABBITIZER_INSTR_ID_cpu_daddiu] = "daddiu",
    [RABBITIZER_INSTR_ID_cpu_lui] = "lui",
    [RABBITIZER_INSTR_ID_cpu_ldl] = "ldl",
    [RABBITIZER_INSTR_ID_cpu_ldr] = "ldr",
    [RABBITIZER_INSTR_ID_cpu_lb] = "lb",
    [RABBITIZER_INSTR_ID_cpu_lh] = "lh",
    [RABBITIZER_INSTR_ID_cpu_lwl] = "lwl",
    [RABBITIZER_INSTR_ID_cpu_lw] = "lw",
    [RABBITIZER_INSTR_ID_cpu_lbu] = "lbu",
    [RABBITIZER_INSTR_ID_cpu_lhu] = "lhu",
    [RABBITIZER_INSTR_ID_cpu_lwr] = "lwr",
    [RABBITIZER_INSTR_ID_cpu_lwu] = "lwu",
    [RABBITIZER_INSTR_ID_cpu_sb] = "sb",
    [RABBITIZER_INSTR_ID_cpu_sh] = "sh",
    [RABBITIZER_INSTR_ID_cpu_swl] = "swl",
    [RABBITIZER_INSTR_ID_cpu_sw] = "sw",
    [RABBITIZER_INSTR_ID_cpu_sdl] = "sdl",
    [RABBITIZER_INSTR_ID_cpu_sdr] = "sdr",
    [RABBITIZER_INSTR_ID_cpu_swr] = "swr",
    [RABBITIZER_INSTR_ID_cpu_ll] = "ll",
    [RABBITIZER_INSTR_ID_cpu_pref] = "pref",
    [RABBITIZER_INSTR_ID_cpu_lld] = "lld",
    [RABBITIZER_INSTR_ID_cpu_ld] = "ld",
    [RABBITIZER_INSTR_ID_cpu_sc] = "sc",
    [RABBITIZER_INSTR_ID_cpu_scd] = "scd",
    [RABBITIZER_INSTR_ID_cpu_sd] = "sd",
    [RABBITIZER_INSTR_ID_cpu_cache] = "cache",
    [RABBITIZER_INSTR_ID_cpu_lwc1] = "lwc1",
    [RABBITIZER_INSTR_ID_cpu_ldc1] = "ldc1",
    [RABBITIZER_INSTR_ID_cpu_swc1] = "swc1",
    [RABBITIZER_INSTR_ID_cpu_sdc1] = "sdc1",
    [RABBITIZER_INSTR_ID_cpu_lwc2] = "lwc2",
    [RABBITIZER_INSTR_ID_cpu_ldc2] = "ldc2",
    [RABBITIZER_INSTR_ID_cpu_swc2] = "swc2",
    [RABBITIZER_INSTR_ID_cpu_sdc2] = "sdc2",
    [RABBITIZER_INSTR_ID_cpu_b] = "b",
    [RABBITIZER_INSTR_ID_cpu_beqz] = "beqz",
    [RABBITIZER_INSTR_ID_cpu_bnez] = "bnez",
    [RABBITIZER_INSTR_ID_cpu_sll] = "sll",
    [RABBITIZER_INSTR_ID_cpu_srl] = "srl",
    [RABBITIZER_INSTR_ID_cpu_sra] = "sra",
    [RABBITIZER_INSTR_ID_cpu_dsll] = "dsll",
    [RABBITIZER_INSTR_ID_cpu_dsrl] = "dsrl",
    [RABBITIZER_INSTR_ID_cpu_dsra] = "dsra",
    [RABBITIZER_INSTR_ID_cpu_dsll32] = "dsll32",
    [RABBITIZER_INSTR_ID_cpu_dsrl32] = "dsrl32",
    [RABBITIZER_INSTR_ID_cpu_dsra32] = "dsra32",
    [RABBITIZER_INSTR_ID_cpu_dsllv] = "dsllv",
    [RABBITIZER_INSTR_ID_cpu_dsrlv] = "dsrlv",
    [RABBITIZER_INSTR_ID_cpu_dsrav] = "dsrav",
    [RABBITIZER_INSTR_ID_cpu_sllv] = "sllv",
    [RABBITIZER_INSTR_ID_cpu_srlv] = "srlv",
    [RABBITIZER_INSTR_ID_cpu_srav] = "srav",
    [RABBITIZER_INSTR_ID_cpu_mthi] = "mthi",
    [RABBITIZER_INSTR_ID_cpu_mtlo] = "mtlo",
    [RABBITIZER_INSTR_ID_cpu_jr] = "jr",
    [RABBITIZER_INSTR_ID_cpu_jalr] = "jalr",
    [RABBITIZER_INSTR_ID_cpu_mfhi] = "mfhi",
    [RABBITIZER_INSTR_ID_cpu_mflo] = "mflo",
    [RABBITIZER_INSTR_ID_cpu_movz] = "movz",
    [RABBITIZER_INSTR_ID_cpu_movn] = "movn",
    [RABBITIZER_INSTR_ID_cpu_div] = "div",
    [RABBITIZER_INSTR_ID_cpu_divu] = "divu",
    [RABBITIZER_INSTR_ID_cpu_sn64_div] = "div",
    [RABBITIZER_INSTR_ID_cpu_sn64_divu] = "divu",
    [RABBITIZER_INSTR_ID_cpu_ddiv] = "ddiv",
    [RABBITIZER_INSTR_ID_cpu_ddivu] = "ddivu",
    [RABBITIZER_INSTR_ID_cpu_add] = "add",
    [RABBITIZER_INSTR_ID_cpu_addu] = "addu",
    [RABBITIZER_INSTR_ID_cpu_sub] = "sub",
    [RABBITIZER_INSTR_ID_cpu_subu] = "subu",
    [RABBITIZER_INSTR_ID_cpu_and] = "and",
    [RABBITIZER_INSTR_ID_cpu_or] = "or",
    [RABBITIZER_INSTR_ID_cpu_xor] = "xor",
    [RABBITIZER_INSTR_ID_cpu_nor] = "nor",
    [RABBITIZER_INSTR_ID_cpu_slt] = "slt",
    [RABBITIZER_INSTR_ID_cpu_sltu] = "sltu",
    [RABBITIZER_INSTR_ID_cpu_dadd] = "dadd",
    [RABBITIZER_INSTR_ID_cpu_daddu] = "daddu",
    [RABBITIZER_INSTR_ID_cpu_dsub] = "dsub",
    [RABBITIZER_INSTR_ID_cpu_dsubu] = "dsubu",
    [RABBITIZER_INSTR_ID_cpu_syscall] = "syscall",
    [RABBITIZER_INSTR_ID_cpu_break] = "break",
    [RABBITIZER_INSTR_ID_cpu_sync] = "sync",
    [RABBITIZER_INSTR_ID_cpu_mult] = "mult",
    [RABBITIZER_INSTR_ID_cpu_multu] = "multu",
    [RABBITIZER_INSTR_ID_cpu_dmult] = "dmult",
    [RABBITIZER_INSTR_ID_cpu_dmultu] = "dmultu",
    [RABBITIZER_INSTR_ID_cpu_tge] = "tge",
    [RABBITIZER_INSTR_ID_cpu_tgeu] = "tgeu",
    [RABBITIZER_INSTR_ID_cpu_tlt] = "tlt",
    [RABBITIZER_INSTR_ID_cpu_tltu] = "tltu",
    [RABBITIZER_INSTR_ID_cpu_teq] = "teq",
    [RABBITIZER_INSTR_ID_cpu_tne] = "tne",
    [RABBITIZER_INSTR_ID_cpu_nop] = "nop",
    [RABBITIZER_INSTR_ID_cpu_move] = "move",
    [RABBITIZER_INSTR_ID_cpu_not] = "not",
    [RABBITIZER_INSTR_ID_cpu_neg] = "neg",
    [RABBITIZER_INSTR_ID_cpu_negu] = "negu",
    [RABBITIZER_INSTR_ID_cpu_bltz] = "bltz",
    [RABBITIZER_INSTR_ID_cpu_bgez] = "bgez",
    [RABBITIZER_INSTR_ID_cpu_bltzl] = "bltzl",
    [RABBITIZER_INSTR_ID_cpu_bgezl] = "bgezl",
    [RABBITIZER_INSTR_ID_cpu_tgei] = "tgei",
    [RABBITIZER_INSTR_ID_cpu_tgeiu] = "tgeiu",
    [RABBITIZER_INSTR_ID_cpu_tlti] = "tlti",
    [RABBITIZER_INSTR_ID_cpu_tltiu] = "tltiu",
    [RABBITIZER_INSTR_ID_cpu_teqi] = "teqi",
    [RABBITIZER_INSTR_ID_cpu_tnei] = "tnei",
    [RABBITIZER_INSTR_ID_cpu_bltzal] = "bltzal",
    [RABBITIZER_INSTR_ID_cpu_bgezal] = "bgezal",
    [RABBITIZER_INSTR_ID_cpu_bltzall] = "bltzall",
    [RABBITIZER_INSTR_ID_cpu_bgezall] = "bgezall",
    [RABBITIZER_INSTR_ID_cpu_bal] = "bal",
    [RABBITIZER_INSTR_ID_cpu_mfc0] = "mfc0",
    [RABBITIZER_INSTR_ID_cpu_dmfc0] = "dmfc0",
    [RABBITIZER_INSTR_ID_cpu_cfc0] = "cfc0",
    [RABBITIZER_INSTR_ID_cpu_mtc0] = "mtc0",
    [RABBITIZER_INSTR_ID_cpu_dmtc0] = "dmtc0",
    [RABBITIZER_INSTR_ID_cpu_ctc0] = "ctc0",
    [RABBITIZER_INSTR_ID_cpu_bc0f] = "bc0f",
    [RABBITIZER_INSTR_ID_cpu_bc0t] = "bc0t",
    [RABBITIZER_INSTR_ID_cpu_bc0fl] = "bc0fl",
    [RABBITIZER_INSTR_ID_cpu_bc0tl] = "bc0tl",
    [RABBITIZER_INSTR_ID_cpu_tlbr] = "tlbr",
    [RABBITIZER_INSTR_ID_cpu_tlbwi] = "tlbwi",
    [RABBITIZER_INSTR_ID_cpu_tlbwr] = "tlbwr",
    [RABBITIZER_INSTR_ID_cpu_tlbp] = "tlbp",
    [RABBITIZER_INSTR_ID_cpu_rfe] = "rfe",
    [RABBITIZER_INSTR_ID_cpu_eret] = "eret",
    [RABBITIZER_INSTR_ID_cpu_mfc1] = "mfc1",
    [RABBITIZER_INSTR_ID_cpu_dmfc1] = "dmfc1",
    [RABBITIZER_INSTR_ID_cpu_mtc1] = "mtc1",
    [RABBITIZER_INSTR_ID_cpu_dmtc1] = "dmtc1",
    [RABBITIZER_INSTR_ID_cpu_cfc1] = "cfc1",
    [RABBITIZER_INSTR_ID_cpu_ctc1] = "ctc1",
    [RABBITIZER_INSTR_ID_cpu_bc1f] = "bc1f",
    [RABBITIZER_INSTR_ID_cpu_bc1t] = "bc1t",
    [RABBITIZER_INSTR_ID_cpu_bc1fl] = "bc1fl",
    [RABBITIZER_INSTR_ID_cpu_bc1tl] = "bc1tl",
    [RABBITIZER_INSTR_ID_cpu_add_s] = "add.s",
    [RABBITIZER_INSTR_ID_cpu_sub_s] = "sub.s",
    [RABBITIZER_INSTR_ID_cpu_mul_s] = "mul.s",
    [RABBITIZER_INSTR_ID_cpu_div_s] = "div.s",
    [RABBITIZER_INSTR_ID_cpu_sqrt_s] = "sqrt.s",
    [RABBITIZER_INSTR_ID_cpu_abs_s] = "abs.s",
    [RABBITIZER_INSTR_ID_cpu_mov_s] = "mov.s",
    [RABBITIZER_INSTR_ID_cpu_neg_s] = "neg.s",
    [RABBITIZER_INSTR_ID_cpu_round_l_s] = "round.l.s",
    [RABBITIZER_INSTR_ID_cpu_trunc_l_s] = "trunc.l.s",
    [RABBITIZER_INSTR_ID_cpu_ceil_l_s] = "ceil.l.s",
    [RABBITIZER_INSTR_ID_cpu_floor_l_s] = "floor.l.s",
    [RABBITIZER_INSTR_ID_cpu_round_w_s] = "round.w.s",
    [RABBITIZER_INSTR_ID_cpu_trunc_w_s] = "trunc.w.s",
    [RABBITIZER_INSTR_ID_cpu_ceil_w_s] = "ceil.w.s",
    [RABBITIZER_INSTR_ID_cpu_floor_w_s] = "floor.w.s",
    [RABBITIZER_INSTR_ID_cpu_cvt_d_s] = "cvt.d.s",
    [RABBITIZER_INSTR_ID_cpu_cvt_w_s] = "cvt.w.s",
    [RABBITIZER_INSTR_ID_cpu_cvt_l_s] = "cvt.l.s",
    [RABBITIZER_INSTR_ID_cpu_c_f_s] = "c.f.s",
    [RABBITIZER_INSTR_ID_cpu_c_un_s] = "c.un.s",
    [RABBITIZER_INSTR_ID_cpu_c_eq_s] = "c.eq.s",
    [RABBITIZER_INSTR_ID_cpu_c_ueq_s] = "c.ueq.s",
    [RABBITIZER_INSTR_ID_cpu_c_olt_s] = "c.olt.s",
    [RABBITIZER_INSTR_ID_cpu_c_ult_s] = "c.ult.s",
    [RABBITIZER_INSTR_ID_cpu_c_ole_s] = "c.ole.s",
    [RABBITIZER_INSTR_ID_cpu_c_ule_s] = "c.ule.s",
    [RABBITIZER_INSTR_ID_cpu_c_sf_s] = "c.sf.s",
    [RABBITIZER_INSTR_ID_cpu_c_ngle_s] = "c.ngle.s",
    [RABBITIZER_INSTR_ID_cpu_c_seq_s] = "c.seq.s",
    [RABBITIZER_INSTR_ID_cpu_c_ngl_s] = "c.ngl.s",
    [RABBITIZER_INSTR_ID_cpu_c_lt_s] = "c.lt.s",
    [RABBITIZER_INSTR_ID_cpu_c_nge_s] = "c.nge.s",
    [RABBITIZER_INSTR_ID_cpu_c_le_s] = "c.le.s",
    [RABBITIZER_INSTR_ID_cpu_c_ngt_s] = "c.ngt.s",
    [RABBITIZER_INSTR_ID_cpu_add_d] = "add.d",
    [RABBITIZER_INSTR_ID_cpu_sub_d] = "sub.d",
    [RABBITIZER_INSTR_ID_cpu_mul_d] = "mul.d",
    [RABBITIZER_INSTR_ID_cpu_div_d] = "div.d",
    [RABBITIZER_INSTR_ID_cpu_sqrt_d] = "sqrt.d",
    [RABBITIZER_INSTR_ID_cpu_abs_d] = "abs.d",
    [RABBITIZER_INSTR_ID_cpu_mov_d] = "mov.d",
    [RABBITIZER_INSTR_ID_cpu_neg_d] = "neg.d",
    [RABBITIZER_INSTR_ID_cpu_round_l_d] = "round.l.d",
    [RABBITIZER_INSTR_ID_cpu_trunc_l_d] = "trunc.l.d",
    [RABBITIZER_INSTR_ID_cpu_ceil_l_d] = "ceil.l.d",
    [RABBITIZER_INSTR_ID_cpu_floor_l_d] = "floor.l.d",
    [RABBITIZER_INSTR_ID_cpu_round_w_d] = "round.w.d",
    [RABBITIZER_INSTR_ID_cpu_trunc_w_d] = "trunc.w.d",
    [RABBITIZER_INSTR_ID_cpu_ceil_w_d] = "ceil.w.d",
    [RABBITIZER_INSTR_ID_cpu_floor_w_d] = "floor.w.d",
    [RABBITIZER_INSTR_ID_cpu_cvt_s_d] = "cvt.s.d",
    [RABBITIZER_INSTR_ID_cpu_cvt_w_d] = "cvt.w.d",
    [RABBITIZER_INSTR_ID_cpu_cvt_l_d] = "cvt.l.d",
    [RABBITIZER_INSTR_ID_cpu_c_f_d] = "c.f.d",
    [RABBITIZER_INSTR_ID_cpu_c_un_d] = "c.un.d",
    [RABBITIZER_INSTR_ID_cpu_c_eq_d] = "c.eq.d",
    [RABBITIZER_INSTR_ID_cpu_c_ueq_d] = "c.ueq.d",
    [RABBITIZER_INSTR_ID_cpu_c_olt_d] = "c.olt.d",
    [RABBITIZER_INSTR_ID_cpu_c_ult_d] = "c.ult.d",
    [RABBITIZER_INSTR_ID_cpu_c_ole_d] = "c.ole.d",
    [RABBITIZER_INSTR_ID_cpu_c_ule_d] = "c.ule.d",
    [RABBITIZER_INSTR_ID_cpu_c_df_d] = "c.df.d",
    [RABBITIZER_INSTR_ID_cpu_c_ngle_d] = "c.ngle.d",
    [RABBITIZER_INSTR_ID_cpu_c_seq_d] = "c.seq.d",
    [RABBITIZER_INSTR_ID_cpu_c_ngl_d] = "c.ngl.d",
    [RABBITIZER_INSTR_ID_cpu_c_lt_d] = "c.lt.d",
    [RABBITIZER_INSTR_ID_cpu_c_nge_d] = "c.nge.d",
    [RABBITIZER_INSTR_ID_cpu_c_le_d] = "c.le.d",
    [RABBITIZER_INSTR_ID_cpu_c_ngt_d] = "c.ngt.d",
    [RABBITIZER_INSTR_ID_cpu_cvt_s_w] = "cvt.s.w",
    [RABBITIZER_INSTR_ID_cpu_cvt_d_w] = "cvt.d.w",
    [RABBITIZER_INSTR_ID_cpu_cvt_s_l] = "cvt.s.l",
    [RABBITIZER_INSTR_ID_cpu_cvt_d_l] = "cvt.d.l",
    [RABBITIZER_INSTR_ID_cpu_mfc2] = "mfc2",
    [RABBITIZER_INSTR_ID_cpu_mtc2] = "mtc2",
    [RABBITIZER_INSTR_ID_cpu_cfc2] = "cfc2",
    [RABBITIZER_INSTR_ID_cpu_ctc2] = "ctc2",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_00] = "USERDEF_00",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_01] = "USERDEF_01",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_02] = "USERDEF_02",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_03] = "USERDEF_03",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_04] = "USERDEF_04",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_05] = "USERDEF_05",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_06] = "USERDEF_06",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_07] = "USERDEF_07",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_08] = "USERDEF_08",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_09] = "USERDEF_09",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_10] = "USERDEF_10",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_11] = "USERDEF_11",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_12] = "USERDEF_12",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_13] = "USERDEF_13",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_14] = "USERDEF_14",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_15] = "USERDEF_15",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_16] = "USERDEF_16",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_17] = "USERDEF_17",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_18] = "USERDEF_18",
    [RABBITIZER_INSTR_ID_cpu_USERDEF_19] = "USERDEF_19",
    [RABBITIZER_INSTR_ID_cpu_MAX] = "MAX",
    [RABBITIZER_INSTR_ID_rsp_INVALID] = "INVALID",
    [RABBITIZER_INSTR_ID_rsp_mfc2] = "mfc2",
    [RABBITIZER_INSTR_ID_rsp_mtc2] = "mtc2",
    [RABBITIZER_INSTR_ID_rsp_cfc2] = "cfc2",
    [RABBITIZER_INSTR_ID_rsp_ctc2] = "ctc2",
    [RABBITIZER_INSTR_ID_rsp_vmulf] = "vmulf",
    [RABBITIZER_INSTR_ID_rsp_vmulu] = "vmulu",
    [RABBITIZER_INSTR_ID_rsp_vrndp] = "vrndp",
    [RABBITIZER_INSTR_ID_rsp_vmulq] = "vmulq",
    [RABBITIZER_INSTR_ID_rsp_vmudl] = "vmudl",
    [RABBITIZER_INSTR_ID_rsp_vmudm] = "vmudm",
    [RABBITIZER_INSTR_ID_rsp_vmudn] = "vmudn",
    [RABBITIZER_INSTR_ID_rsp_vmudh] = "vmudh",
    [RABBITIZER_INSTR_ID_rsp_vmacf] = "vmacf",
    [RABBITIZER_INSTR_ID_rsp_vmacu] = "vmacu",
    [RABBITIZER_INSTR_ID_rsp_vrndn] = "vrndn",
    [RABBITIZER_INSTR_ID_rsp_vmacq] = "vmacq",
    [RABBITIZER_INSTR_ID_rsp_vmadl] = "vmadl",
    [RABBITIZER_INSTR_ID_rsp_vmadm] = "vmadm",
    [RABBITIZER_INSTR_ID_rsp_vmadn] = "vmadn",
    [RABBITIZER_INSTR_ID_rsp_vmadh] = "vmadh",
    [RABBITIZER_INSTR_ID_rsp_vadd] = "vadd",
    [RABBITIZER_INSTR_ID_rsp_vsub] = "vsub",
    [RABBITIZER_INSTR_ID_rsp_vabs] = "vabs",
    [RABBITIZER_INSTR_ID_rsp_vaddc] = "vaddc",
    [RABBITIZER_INSTR_ID_rsp_vsubc] = "vsubc",
    [RABBITIZER_INSTR_ID_rsp_vsar] = "vsar",
    [RABBITIZER_INSTR_ID_rsp_vand] = "vand",
    [RABBITIZER_INSTR_ID_rsp_vnand] = "vnand",
    [RABBITIZER_INSTR_ID_rsp_vor] = "vor",
    [RABBITIZER_INSTR_ID_rsp_vnor] = "vnor",
    [RABBITIZER_INSTR_ID_rsp_vxor] = "vxor",
    [RABBITIZER_INSTR_ID_rsp_vnxor] = "vnxor",
    [RABBITIZER_INSTR_ID_rsp_vlt] = "vlt",
    [RABBITIZER_INSTR_ID_rsp_veq] = "veq",
    [RABBITIZER_INSTR_ID_rsp_vne] = "vne",
    [RABBITIZER_INSTR_ID_rsp_vge] = "vge",
    [RABBITIZER_INSTR_ID_rsp_vcl] = "vcl",
    [RABBITIZER_INSTR_ID_rsp_vch] = "vch",
    [RABBITIZER_INSTR_ID_rsp_vcr] = "vcr",
    [RABBITIZER_INSTR_ID_rsp_vmrg] = "vmrg",
    [RABBITIZER_INSTR_ID_rsp_vrcp] = "vrcp",
    [RABBITIZER_INSTR_ID_rsp_vrcpl] = "vrcpl",
    [RABBITIZER_INSTR_ID_rsp_vrcph] = "vrcph",
    [RABBITIZER_INSTR_ID_rsp_vmov] = "vmov",
    [RABBITIZER_INSTR_ID_rsp_vrsq] = "vrsq",
    [RABBITIZER_INSTR_ID_rsp_vrsql] = "vrsql",
    [RABBITIZER_INSTR_ID_rsp_vrsqh] = "vrsqh",
    [RABBITIZER_INSTR_ID_rsp_vnop] = "vnop",
    [RABBITIZER_INSTR_ID_rsp_lbv] = "lbv",
    [RABBITIZER_INSTR_ID_rsp_lsv] = "lsv",
    [RABBITIZER_INSTR_ID_rsp_llv] = "llv",
    [RABBITIZER_INSTR_ID_rsp_ldv] = "ldv",
    [RABBITIZER_INSTR_ID_rsp_lqv] = "lqv",
    [RABBITIZER_INSTR_ID_rsp_lrv] = "lrv",
    [RABBITIZER_INSTR_ID_rsp_lpv] = "lpv",
    [RABBITIZER_INSTR_ID_rsp_luv] = "luv",
    [RABBITIZER_INSTR_ID_rsp_lhv] = "lhv",
    [RABBITIZER_INSTR_ID_rsp_lfv] = "lfv",
    [RABBITIZER_INSTR_ID_rsp_ltv] = "ltv",
    [RABBITIZER_INSTR_ID_rsp_sbv] = "sbv",
    [RABBITIZER_INSTR_ID_rsp_ssv] = "ssv",
    [RABBITIZER_INSTR_ID_rsp_slv] = "slv",
    [RABBITIZER_INSTR_ID_rsp_sdv] = "sdv",
    [RABBITIZER_INSTR_ID_rsp_sqv] = "sqv",
    [RABBITIZER_INSTR_ID_rsp_srv] = "srv",
    [RABBITIZER_INSTR_ID_rsp_spv] = "spv",
    [RABBITIZER_INSTR_ID_rsp_suv] = "suv",
    [RABBITIZER_INSTR_ID_rsp_shv] = "shv",
    [RABBITIZER_INSTR_ID_rsp_sfv] = "sfv",
    [RABBITIZER_INSTR_ID_rsp_stv] = "stv",
    [RABBITIZER_INSTR_ID_rsp_swv] = "swv",
    [RABBITIZER_INSTR_ID_rsp_j] = "j",
    [RABBITIZER_INSTR_ID_rsp_jal] = "jal",
    [RABBITIZER_INSTR_ID_rsp_beq] = "beq",
    [RABBITIZER_INSTR_ID_rsp_bne] = "bne",
    [RABBITIZER_INSTR_ID_rsp_blez] = "blez",
    [RABBITIZER_INSTR_ID_rsp_bgtz] = "bgtz",
    [RABBITIZER_INSTR_ID_rsp_addi] = "addi",
    [RABBITIZER_INSTR_ID_rsp_addiu] = "addiu",
    [RABBITIZER_INSTR_ID_rsp_slti] = "slti",
    [RABBITIZER_INSTR_ID_rsp_sltiu] = "sltiu",
    [RABBITIZER_INSTR_ID_rsp_andi] = "andi",
    [RABBITIZER_INSTR_ID_rsp_ori] = "ori",
    [RABBITIZER_INSTR_ID_rsp_xori] = "xori",
    [RABBITIZER_INSTR_ID_rsp_lui] = "lui",
    [RABBITIZER_INSTR_ID_rsp_lb] = "lb",
    [RABBITIZER_INSTR_ID_rsp_lh] = "lh",
    [RABBITIZER_INSTR_ID_rsp_lw] = "lw",
    [RABBITIZER_INSTR_ID_rsp_lbu] = "lbu",
    [RABBITIZER_INSTR_ID_rsp_lhu] = "lhu",
    [RABBITIZER_INSTR_ID_rsp_sb] = "sb",
    [RABBITIZER_INSTR_ID_rsp_sh] = "sh",
    [RABBITIZER_INSTR_ID_rsp_sw] = "sw",
    [RABBITIZER_INSTR_ID_rsp_pref] = "pref",
    [RABBITIZER_INSTR_ID_rsp_b] = "b",
    [RABBITIZER_INSTR_ID_rsp_beqz] = "beqz",
    [RABBITIZER_INSTR_ID_rsp_bnez] = "bnez",
    [RABBITIZER_INSTR_ID_rsp_sll] = "sll",
    [RABBITIZER_INSTR_ID_rsp_srl] = "srl",
    [RABBITIZER_INSTR_ID_rsp_sra] = "sra",
    [RABBITIZER_INSTR_ID_rsp_sllv] = "sllv",
    [RABBITIZER_INSTR_ID_rsp_srlv] = "srlv",
    [RABBITIZER_INSTR_ID_rsp_srav] = "srav",
    [RABBITIZER_INSTR_ID_rsp_jr] = "jr",
    [RABBITIZER_INSTR_ID_rsp_jalr] = "jalr",
    [RABBITIZER_INSTR_ID_rsp_movz] = "movz",
    [RABBITIZER_INSTR_ID_rsp_movn] = "movn",
    [RABBITIZER_INSTR_ID_rsp_add] = "add",
    [RABBITIZER_INSTR_ID_rsp_addu] = "addu",
    [RABBITIZER_INSTR_ID_rsp_sub] = "sub",
    [RABBITIZER_INSTR_ID_rsp_subu] = "subu",
    [RABBITIZER_INSTR_ID_rsp_and] = "and",
    [RABBITIZER_INSTR_ID_rsp_or] = "or",
    [RABBITIZER_INSTR_ID_rsp_xor] = "xor",
    [RABBITIZER_INSTR_ID_rsp_nor] = "nor",
    [RABBITIZER_INSTR_ID_rsp_slt] = "slt",
    [RABBITIZER_INSTR_ID_rsp_sltu] = "sltu",
    [RABBITIZER_INSTR_ID_rsp_break] = "break",
    [RABBITIZER_INSTR_ID_rsp_nop] = "nop",
    [RABBITIZER_INSTR_ID_rsp_move] = "move",
    [RABBITIZER_INSTR_ID_rsp_not] = "not",
    [RABBITIZER_INSTR_ID_rsp_neg] = "neg",
    [RABBITIZER_INSTR_ID_rsp_negu] = "negu",
    [RABBITIZER_INSTR_ID_rsp_bltz] = "bltz",
    [RABBITIZER_INSTR_ID_rsp_bgez] = "bgez",
    [RABBITIZER_INSTR_ID_rsp_bltzal] = "bltzal",
    [RABBITIZER_INSTR_ID_rsp_bgezal] = "bgezal",
    [RABBITIZER_INSTR_ID_rsp_bal] = "bal",
    [RABBITIZER_INSTR_ID_rsp_mfc0] = "mfc0",
    [RABBITIZER_INSTR_ID_rsp_mtc0] = "mtc0",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_00] = "USERDEF_00",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_01] = "USERDEF_01",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_02] = "USERDEF_02",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_03] = "USERDEF_03",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_04] = "USERDEF_04",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_05] = "USERDEF_05",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_06] = "USERDEF_06",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_07] = "USERDEF_07",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_08] = "USERDEF_08",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_09] = "USERDEF_09",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_10] = "USERDEF_10",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_11] = "USERDEF_11",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_12] = "USERDEF_12",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_13] = "USERDEF_13",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_14] = "USERDEF_14",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_15] = "USERDEF_15",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_16] = "USERDEF_16",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_17] = "USERDEF_17",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_18] = "USERDEF_18",
    [RABBITIZER_INSTR_ID_rsp_USERDEF_19] = "USERDEF_19",
    [RABBITIZER_INSTR_ID_rsp_MAX] = "MAX",
    [RABBITIZER_INSTR_ID_r3000gte_INVALID] = "INVALID",
    [RABBITIZER_INSTR_ID_r3000gte_rtps] = "rtps",
    [RABBITIZER_INSTR_ID_r3000gte_rtpt] = "rtpt",
    [RABBITIZER_INSTR_ID_r3000gte_dpcl] = "dpcl",
    [RABBITIZER_INSTR_ID_r3000gte_dpcs] = "dpcs",
    [RABBITIZER_INSTR_ID_r3000gte_dpct] = "dpct",
    [RABBITIZER_INSTR_ID_r3000gte_intpl] = "intpl",
    [RABBITIZER_INSTR_ID_r3000gte_ncs] = "ncs",
    [RABBITIZER_INSTR_ID_r3000gte_nct] = "nct",
    [RABBITIZER_INSTR_ID_r3000gte_ncds] = "ncds",
    [RABBITIZER_INSTR_ID_r3000gte_ncdt] = "ncdt",
    [RABBITIZER_INSTR_ID_r3000gte_nccs] = "nccs",
    [RABBITIZER_INSTR_ID_r3000gte_ncct] = "ncct",
    [RABBITIZER_INSTR_ID_r3000gte_cdp] = "cdp",
    [RABBITIZER_INSTR_ID_r3000gte_cc] = "cc",
    [RABBITIZER_INSTR_ID_r3000gte_nclip] = "nclip",
    [RABBITIZER_INSTR_ID_r3000gte_avsz3] = "avsz3",
    [RABBITIZER_INSTR_ID_r3000gte_avsz4] = "avsz4",
    [RABBITIZER_INSTR_ID_r3000gte_mvmva] = "mvmva",
    [RABBITIZER_INSTR_ID_r3000gte_sqr] = "sqr",
    [RABBITIZER_INSTR_ID_r3000gte_op] = "op",
    [RABBITIZER_INSTR_ID_r3000gte_gpf] = "gpf",
    [RABBITIZER_INSTR_ID_r3000gte_gpl] = "gpl",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_00] = "USERDEF_00",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_01] = "USERDEF_01",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_02] = "USERDEF_02",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_03] = "USERDEF_03",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_04] = "USERDEF_04",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_05] = "USERDEF_05",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_06] = "USERDEF_06",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_07] = "USERDEF_07",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_08] = "USERDEF_08",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_09] = "USERDEF_09",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_10] = "USERDEF_10",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_11] = "USERDEF_11",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_12] = "USERDEF_12",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_13] = "USERDEF_13",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_14] = "USERDEF_14",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_15] = "USERDEF_15",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_16] = "USERDEF_16",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_17] = "USERDEF_17",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_18] = "USERDEF_18",
    [RABBITIZER_INSTR_ID_r3000gte_USERDEF_19] = "USERDEF_19",
    [RABBITIZER_INSTR_ID_r3000gte_MAX] = "MAX",
    [RABBITIZER_INSTR_ID_r4000allegrex_INVALID] = "INVALID",
    [RABBITIZER_INSTR_ID_r4000allegrex_lv_s] = "lv.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_sv_s] = "sv.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_lv_q] = "lv.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_sv_q] = "sv.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_clz] = "clz",
    [RABBITIZER_INSTR_ID_r4000allegrex_clo] = "clo",
    [RABBITIZER_INSTR_ID_r4000allegrex_madd] = "madd",
    [RABBITIZER_INSTR_ID_r4000allegrex_maddu] = "maddu",
    [RABBITIZER_INSTR_ID_r4000allegrex_msub] = "msub",
    [RABBITIZER_INSTR_ID_r4000allegrex_msubu] = "msubu",
    [RABBITIZER_INSTR_ID_r4000allegrex_max] = "max",
    [RABBITIZER_INSTR_ID_r4000allegrex_min] = "min",
    [RABBITIZER_INSTR_ID_r4000allegrex_srl] = "srl",
    [RABBITIZER_INSTR_ID_r4000allegrex_rotr] = "rotr",
    [RABBITIZER_INSTR_ID_r4000allegrex_srlv] = "srlv",
    [RABBITIZER_INSTR_ID_r4000allegrex_rotrv] = "rotrv",
    [RABBITIZER_INSTR_ID_r4000allegrex_sleep] = "sleep",
    [RABBITIZER_INSTR_ID_r4000allegrex_mfie] = "mfie",
    [RABBITIZER_INSTR_ID_r4000allegrex_mtie] = "mtie",
    [RABBITIZER_INSTR_ID_r4000allegrex_ext] = "ext",
    [RABBITIZER_INSTR_ID_r4000allegrex_ins] = "ins",
    [RABBITIZER_INSTR_ID_r4000allegrex_wsbh] = "wsbh",
    [RABBITIZER_INSTR_ID_r4000allegrex_wsbw] = "wsbw",
    [RABBITIZER_INSTR_ID_r4000allegrex_seb] = "seb",
    [RABBITIZER_INSTR_ID_r4000allegrex_seh] = "seh",
    [RABBITIZER_INSTR_ID_r4000allegrex_bitrev] = "bitrev",
    [RABBITIZER_INSTR_ID_r4000allegrex_bvf] = "bvf",
    [RABBITIZER_INSTR_ID_r4000allegrex_bvt] = "bvt",
    [RABBITIZER_INSTR_ID_r4000allegrex_bvfl] = "bvfl",
    [RABBITIZER_INSTR_ID_r4000allegrex_bvtl] = "bvtl",
    [RABBITIZER_INSTR_ID_r4000allegrex_mfv] = "mfv",
    [RABBITIZER_INSTR_ID_r4000allegrex_mfvc] = "mfvc",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsync2] = "vsync2",
    [RABBITIZER_INSTR_ID_r4000allegrex_mtv] = "mtv",
    [RABBITIZER_INSTR_ID_r4000allegrex_mtvc] = "mtvc",
    [RABBITIZER_INSTR_ID_r4000allegrex_vadd_s] = "vadd.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vadd_p] = "vadd.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vadd_t] = "vadd.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vadd_q] = "vadd.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsub_s] = "vsub.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsub_p] = "vsub.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsub_t] = "vsub.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsub_q] = "vsub.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsbn_s] = "vsbn.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vdiv_s] = "vdiv.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vdiv_p] = "vdiv.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vdiv_t] = "vdiv.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vdiv_q] = "vdiv.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmul_s] = "vmul.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmul_p] = "vmul.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmul_t] = "vmul.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmul_q] = "vmul.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vdot_p] = "vdot.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vdot_t] = "vdot.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vdot_q] = "vdot.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vscl_p] = "vscl.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vscl_t] = "vscl.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vscl_q] = "vscl.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vhdp_p] = "vhdp.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vhdp_t] = "vhdp.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vhdp_q] = "vhdp.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcrs_t] = "vcrs.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vdet_p] = "vdet.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmp_s] = "vcmp.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmp_p] = "vcmp.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmp_t] = "vcmp.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmp_q] = "vcmp.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmin_s] = "vmin.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmin_p] = "vmin.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmin_t] = "vmin.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmin_q] = "vmin.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmax_s] = "vmax.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmax_p] = "vmax.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmax_t] = "vmax.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmax_q] = "vmax.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vscmp_s] = "vscmp.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vscmp_p] = "vscmp.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vscmp_t] = "vscmp.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vscmp_q] = "vscmp.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsge_s] = "vsge.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsge_p] = "vsge.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsge_t] = "vsge.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsge_q] = "vsge.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vslt_s] = "vslt.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vslt_p] = "vslt.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vslt_t] = "vslt.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vslt_q] = "vslt.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vwbn_s] = "vwbn.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmov_s] = "vmov.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmov_p] = "vmov.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmov_t] = "vmov.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmov_q] = "vmov.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vabs_s] = "vabs.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vabs_p] = "vabs.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vabs_t] = "vabs.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vabs_q] = "vabs.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vneg_s] = "vneg.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vneg_p] = "vneg.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vneg_t] = "vneg.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vneg_q] = "vneg.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vidt_p] = "vidt.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vidt_q] = "vidt.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsat0_s] = "vsat0.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsat0_p] = "vsat0.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsat0_t] = "vsat0.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsat0_q] = "vsat0.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsat1_s] = "vsat1.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsat1_p] = "vsat1.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsat1_t] = "vsat1.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsat1_q] = "vsat1.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vzero_s] = "vzero.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vzero_p] = "vzero.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vzero_t] = "vzero.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vzero_q] = "vzero.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vone_s] = "vone.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vone_p] = "vone.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vone_t] = "vone.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vone_q] = "vone.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrcp_s] = "vrcp.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrcp_p] = "vrcp.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrcp_t] = "vrcp.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrcp_q] = "vrcp.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrsq_s] = "vrsq.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrsq_p] = "vrsq.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrsq_t] = "vrsq.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrsq_q] = "vrsq.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsin_s] = "vsin.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsin_p] = "vsin.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsin_t] = "vsin.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsin_q] = "vsin.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcos_s] = "vcos.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcos_p] = "vcos.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcos_t] = "vcos.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcos_q] = "vcos.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vexp2_s] = "vexp2.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vexp2_p] = "vexp2.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vexp2_t] = "vexp2.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vexp2_q] = "vexp2.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vlog2_s] = "vlog2.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vlog2_p] = "vlog2.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vlog2_t] = "vlog2.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vlog2_q] = "vlog2.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsqrt_s] = "vsqrt.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsqrt_p] = "vsqrt.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsqrt_t] = "vsqrt.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsqrt_q] = "vsqrt.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vasin_s] = "vasin.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vasin_p] = "vasin.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vasin_t] = "vasin.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vasin_q] = "vasin.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vnrcp_s] = "vnrcp.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vnrcp_p] = "vnrcp.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vnrcp_t] = "vnrcp.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vnrcp_q] = "vnrcp.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vnsin_s] = "vnsin.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vnsin_p] = "vnsin.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vnsin_t] = "vnsin.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vnsin_q] = "vnsin.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrexp2_s] = "vrexp2.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrexp2_p] = "vrexp2.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrexp2_t] = "vrexp2.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrexp2_q] = "vrexp2.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrnds_s] = "vrnds.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndi_s] = "vrndi.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndi_p] = "vrndi.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndi_t] = "vrndi.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndi_q] = "vrndi.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndf1_s] = "vrndf1.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndf1_p] = "vrndf1.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndf1_t] = "vrndf1.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndf1_q] = "vrndf1.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndf2_s] = "vrndf2.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndf2_p] = "vrndf2.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndf2_t] = "vrndf2.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrndf2_q] = "vrndf2.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2h_p] = "vf2h.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2h_q] = "vf2h.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vh2f_s] = "vh2f.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vh2f_p] = "vh2f.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsbz_s] = "vsbz.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vlgb_s] = "vlgb.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vuc2ifs_s] = "vuc2ifs.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vc2i_s] = "vc2i.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vus2i_s] = "vus2i.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vus2i_p] = "vus2i.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vs2i_s] = "vs2i.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vs2i_p] = "vs2i.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2uc_q] = "vi2uc.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2c_q] = "vi2c.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2us_p] = "vi2us.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2us_q] = "vi2us.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2s_p] = "vi2s.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2s_q] = "vi2s.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsrt1_q] = "vsrt1.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsrt2_q] = "vsrt2.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vbfy1_p] = "vbfy1.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vbfy1_q] = "vbfy1.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vbfy2_q] = "vbfy2.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vocp_s] = "vocp.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vocp_p] = "vocp.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vocp_t] = "vocp.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vocp_q] = "vocp.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsocp_s] = "vsocp.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsocp_p] = "vsocp.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vfad_p] = "vfad.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vfad_t] = "vfad.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vfad_q] = "vfad.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vavg_p] = "vavg.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vavg_t] = "vavg.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vavg_q] = "vavg.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsrt3_q] = "vsrt3.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsrt4_q] = "vsrt4.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsgn_s] = "vsgn.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsgn_p] = "vsgn.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsgn_t] = "vsgn.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsgn_q] = "vsgn.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmfvc] = "vmfvc",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmtvc] = "vmtvc",
    [RABBITIZER_INSTR_ID_r4000allegrex_vt4444_q] = "vt4444.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vt5551_q] = "vt5551.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vt5650_q] = "vt5650.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcst_s] = "vcst.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcst_p] = "vcst.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcst_t] = "vcst.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcst_q] = "vcst.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2in_s] = "vf2in.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2in_p] = "vf2in.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2in_t] = "vf2in.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2in_q] = "vf2in.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2iz_s] = "vf2iz.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2iz_p] = "vf2iz.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2iz_t] = "vf2iz.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2iz_q] = "vf2iz.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2iu_s] = "vf2iu.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2iu_p] = "vf2iu.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2iu_t] = "vf2iu.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2iu_q] = "vf2iu.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2id_s] = "vf2id.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2id_p] = "vf2id.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2id_t] = "vf2id.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vf2id_q] = "vf2id.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2f_s] = "vi2f.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2f_p] = "vi2f.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2f_t] = "vi2f.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vi2f_q] = "vi2f.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmovt_s] = "vcmovt.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmovt_p] = "vcmovt.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmovt_t] = "vcmovt.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmovt_q] = "vcmovt.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmovf_s] = "vcmovf.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmovf_p] = "vcmovf.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmovf_t] = "vcmovf.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcmovf_q] = "vcmovf.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vpfxs] = "vpfxs",
    [RABBITIZER_INSTR_ID_r4000allegrex_vpfxt] = "vpfxt",
    [RABBITIZER_INSTR_ID_r4000allegrex_vpfxd] = "vpfxd",
    [RABBITIZER_INSTR_ID_r4000allegrex_viim_s] = "viim.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vfim_s] = "vfim.s",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmmul_p] = "vmmul.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmmul_t] = "vmmul.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmmul_q] = "vmmul.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vhtfm2_p] = "vhtfm2.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vtfm2_p] = "vtfm2.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vhtfm3_t] = "vhtfm3.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vtfm3_t] = "vtfm3.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vhtfm4_q] = "vhtfm4.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vtfm4_q] = "vtfm4.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmscl_p] = "vmscl.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmscl_t] = "vmscl.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmscl_q] = "vmscl.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vcrsp_t] = "vcrsp.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vqmul_q] = "vqmul.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrot_p] = "vrot.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrot_t] = "vrot.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vrot_q] = "vrot.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmmov_p] = "vmmov.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmmov_t] = "vmmov.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmmov_q] = "vmmov.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmidt_p] = "vmidt.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmidt_t] = "vmidt.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmidt_q] = "vmidt.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmzero_p] = "vmzero.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmzero_t] = "vmzero.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmzero_q] = "vmzero.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmone_p] = "vmone.p",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmone_t] = "vmone.t",
    [RABBITIZER_INSTR_ID_r4000allegrex_vmone_q] = "vmone.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_vnop] = "vnop",
    [RABBITIZER_INSTR_ID_r4000allegrex_vsync] = "vsync",
    [RABBITIZER_INSTR_ID_r4000allegrex_vflush] = "vflush",
    [RABBITIZER_INSTR_ID_r4000allegrex_svl_q] = "svl.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_svr_q] = "svr.q",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_00] = "USERDEF_00",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_01] = "USERDEF_01",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_02] = "USERDEF_02",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_03] = "USERDEF_03",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_04] = "USERDEF_04",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_05] = "USERDEF_05",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_06] = "USERDEF_06",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_07] = "USERDEF_07",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_08] = "USERDEF_08",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_09] = "USERDEF_09",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_10] = "USERDEF_10",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_11] = "USERDEF_11",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_12] = "USERDEF_12",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_13] = "USERDEF_13",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_14] = "USERDEF_14",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_15] = "USERDEF_15",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_16] = "USERDEF_16",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_17] = "USERDEF_17",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_18] = "USERDEF_18",
    [RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_19] = "USERDEF_19",
    [RABBITIZER_INSTR_ID_r4000allegrex_MAX] = "MAX",
    [RABBITIZER_INSTR_ID_r5900_INVALID] = "INVALID",
    [RABBITIZER_INSTR_ID_r5900_lq] = "lq",
    [RABBITIZER_INSTR_ID_r5900_sq] = "sq",
    [RABBITIZER_INSTR_ID_r5900_lqc2] = "lqc2",
    [RABBITIZER_INSTR_ID_r5900_sqc2] = "sqc2",
    [RABBITIZER_INSTR_ID_r5900_sync_p] = "sync.p",
    [RABBITIZER_INSTR_ID_r5900_mult] = "mult",
    [RABBITIZER_INSTR_ID_r5900_mfsa] = "mfsa",
    [RABBITIZER_INSTR_ID_r5900_mtsa] = "mtsa",
    [RABBITIZER_INSTR_ID_r5900_mtsab] = "mtsab",
    [RABBITIZER_INSTR_ID_r5900_mtsah] = "mtsah",
    [RABBITIZER_INSTR_ID_r5900_madd] = "madd",
    [RABBITIZER_INSTR_ID_r5900_maddu] = "maddu",
    [RABBITIZER_INSTR_ID_r5900_plzcw] = "plzcw",
    [RABBITIZER_INSTR_ID_r5900_mfhi1] = "mfhi1",
    [RABBITIZER_INSTR_ID_r5900_mthi1] = "mthi1",
    [RABBITIZER_INSTR_ID_r5900_mflo1] = "mflo1",
    [RABBITIZER_INSTR_ID_r5900_mtlo1] = "mtlo1",
    [RABBITIZER_INSTR_ID_r5900_mult1] = "mult1",
    [RABBITIZER_INSTR_ID_r5900_multu1] = "multu1",
    [RABBITIZER_INSTR_ID_r5900_div1] = "div1",
    [RABBITIZER_INSTR_ID_r5900_divu1] = "divu1",
    [RABBITIZER_INSTR_ID_r5900_madd1] = "madd1",
    [RABBITIZER_INSTR_ID_r5900_maddu1] = "maddu1",
    [RABBITIZER_INSTR_ID_r5900_psllh] = "psllh",
    [RABBITIZER_INSTR_ID_r5900_psrlh] = "psrlh",
    [RABBITIZER_INSTR_ID_r5900_psrah] = "psrah",
    [RABBITIZER_INSTR_ID_r5900_psllw] = "psllw",
    [RABBITIZER_INSTR_ID_r5900_psrlw] = "psrlw",
    [RABBITIZER_INSTR_ID_r5900_psraw] = "psraw",
    [RABBITIZER_INSTR_ID_r5900_paddw] = "paddw",
    [RABBITIZER_INSTR_ID_r5900_psubw] = "psubw",
    [RABBITIZER_INSTR_ID_r5900_pcgtw] = "pcgtw",
    [RABBITIZER_INSTR_ID_r5900_pmaxw] = "pmaxw",
    [RABBITIZER_INSTR_ID_r5900_paddh] = "paddh",
    [RABBITIZER_INSTR_ID_r5900_psubh] = "psubh",
    [RABBITIZER_INSTR_ID_r5900_pcgth] = "pcgth",
    [RABBITIZER_INSTR_ID_r5900_pmaxh] = "pmaxh",
    [RABBITIZER_INSTR_ID_r5900_paddb] = "paddb",
    [RABBITIZER_INSTR_ID_r5900_psubb] = "psubb",
    [RABBITIZER_INSTR_ID_r5900_pcgtb] = "pcgtb",
    [RABBITIZER_INSTR_ID_r5900_paddsw] = "paddsw",
    [RABBITIZER_INSTR_ID_r5900_psubsw] = "psubsw",
    [RABBITIZER_INSTR_ID_r5900_pextlw] = "pextlw",
    [RABBITIZER_INSTR_ID_r5900_ppacw] = "ppacw",
    [RABBITIZER_INSTR_ID_r5900_paddsh] = "paddsh",
    [RABBITIZER_INSTR_ID_r5900_psubsh] = "psubsh",
    [RABBITIZER_INSTR_ID_r5900_pextlh] = "pextlh",
    [RABBITIZER_INSTR_ID_r5900_ppach] = "ppach",
    [RABBITIZER_INSTR_ID_r5900_paddsb] = "paddsb",
    [RABBITIZER_INSTR_ID_r5900_psubsb] = "psubsb",
    [RABBITIZER_INSTR_ID_r5900_pextlb] = "pextlb",
    [RABBITIZER_INSTR_ID_r5900_ppacb] = "ppacb",
    [RABBITIZER_INSTR_ID_r5900_pext5] = "pext5",
    [RABBITIZER_INSTR_ID_r5900_ppac5] = "ppac5",
    [RABBITIZER_INSTR_ID_r5900_pabsw] = "pabsw",
    [RABBITIZER_INSTR_ID_r5900_pceqw] = "pceqw",
    [RABBITIZER_INSTR_ID_r5900_pminw] = "pminw",
    [RABBITIZER_INSTR_ID_r5900_padsbh] = "padsbh",
    [RABBITIZER_INSTR_ID_r5900_pabsh] = "pabsh",
    [RABBITIZER_INSTR_ID_r5900_pceqh] = "pceqh",
    [RABBITIZER_INSTR_ID_r5900_pminh] = "pminh",
    [RABBITIZER_INSTR_ID_r5900_pceqb] = "pceqb",
    [RABBITIZER_INSTR_ID_r5900_padduw] = "padduw",
    [RABBITIZER_INSTR_ID_r5900_psubuw] = "psubuw",
    [RABBITIZER_INSTR_ID_r5900_pextuw] = "pextuw",
    [RABBITIZER_INSTR_ID_r5900_padduh] = "padduh",
    [RABBITIZER_INSTR_ID_r5900_psubuh] = "psubuh",
    [RABBITIZER_INSTR_ID_r5900_pextuh] = "pextuh",
    [RABBITIZER_INSTR_ID_r5900_paddub] = "paddub",
    [RABBITIZER_INSTR_ID_r5900_psubub] = "psubub",
    [RABBITIZER_INSTR_ID_r5900_pextub] = "pextub",
    [RABBITIZER_INSTR_ID_r5900_qfsrv] = "qfsrv",
    [RABBITIZER_INSTR_ID_r5900_pmaddw] = "pmaddw",
    [RABBITIZER_INSTR_ID_r5900_psllvw] = "psllvw",
    [RABBITIZER_INSTR_ID_r5900_psrlvw] = "psrlvw",
    [RABBITIZER_INSTR_ID_r5900_pmsubw] = "pmsubw",
    [RABBITIZER_INSTR_ID_r5900_pmfhi] = "pmfhi",
    [RABBITIZER_INSTR_ID_r5900_pmflo] = "pmflo",
    [RABBITIZER_INSTR_ID_r5900_pinth] = "pinth",
    [RABBITIZER_INSTR_ID_r5900_pmultw] = "pmultw",
    [RABBITIZER_INSTR_ID_r5900_pdivw] = "pdivw",
    [RABBITIZER_INSTR_ID_r5900_pcpyld] = "pcpyld",
    [RABBITIZER_INSTR_ID_r5900_pmaddh] = "pmaddh",
    [RABBITIZER_INSTR_ID_r5900_phmadh] = "phmadh",
    [RABBITIZER_INSTR_ID_r5900_pand] = "pand",
    [RABBITIZER_INSTR_ID_r5900_pxor] = "pxor",
    [RABBITIZER_INSTR_ID_r5900_pmsubh] = "pmsubh",
    [RABBITIZER_INSTR_ID_r5900_phmsbh] = "phmsbh",
    [RABBITIZER_INSTR_ID_r5900_pexeh] = "pexeh",
    [RABBITIZER_INSTR_ID_r5900_prevh] = "prevh",
    [RABBITIZER_INSTR_ID_r5900_pmulth] = "pmulth",
    [RABBITIZER_INSTR_ID_r5900_pdivbw] = "pdivbw",
    [RABBITIZER_INSTR_ID_r5900_pexew] = "pexew",
    [RABBITIZER_INSTR_ID_r5900_prot3w] = "prot3w",
    [RABBITIZER_INSTR_ID_r5900_pmadduw] = "pmadduw",
    [RABBITIZER_INSTR_ID_r5900_psravw] = "psravw",
    [RABBITIZER_INSTR_ID_r5900_pmthi] = "pmthi",
    [RABBITIZER_INSTR_ID_r5900_pmtlo] = "pmtlo",
    [RABBITIZER_INSTR_ID_r5900_pinteh] = "pinteh",
    [RABBITIZER_INSTR_ID_r5900_pmultuw] = "pmultuw",
    [RABBITIZER_INSTR_ID_r5900_pdivuw] = "pdivuw",
    [RABBITIZER_INSTR_ID_r5900_pcpyud] = "pcpyud",
    [RABBITIZER_INSTR_ID_r5900_por] = "por",
    [RABBITIZER_INSTR_ID_r5900_pnor] = "pnor",
    [RABBITIZER_INSTR_ID_r5900_pexch] = "pexch",
    [RABBITIZER_INSTR_ID_r5900_pcpyh] = "pcpyh",
    [RABBITIZER_INSTR_ID_r5900_pexcw] = "pexcw",
    [RABBITIZER_INSTR_ID_r5900_pmfhl_lw] = "pmfhl.lw",
    [RABBITIZER_INSTR_ID_r5900_pmfhl_uw] = "pmfhl.uw",
    [RABBITIZER_INSTR_ID_r5900_pmfhl_slw] = "pmfhl.slw",
    [RABBITIZER_INSTR_ID_r5900_pmfhl_lh] = "pmfhl.lh",
    [RABBITIZER_INSTR_ID_r5900_pmfhl_sh] = "pmfhl.sh",
    [RABBITIZER_INSTR_ID_r5900_pmthl_lw] = "pmthl.lw",
    [RABBITIZER_INSTR_ID_r5900_ei] = "ei",
    [RABBITIZER_INSTR_ID_r5900_di] = "di",
    [RABBITIZER_INSTR_ID_r5900_c1__sqrt_s] = "c1",
    [RABBITIZER_INSTR_ID_r5900_rsqrt_s] = "rsqrt.s",
    [RABBITIZER_INSTR_ID_r5900_adda_s] = "adda.s",
    [RABBITIZER_INSTR_ID_r5900_suba_s] = "suba.s",
    [RABBITIZER_INSTR_ID_r5900_mula_s] = "mula.s",
    [RABBITIZER_INSTR_ID_r5900_madd_s] = "madd.s",
    [RABBITIZER_INSTR_ID_r5900_msub_s] = "msub.s",
    [RABBITIZER_INSTR_ID_r5900_madda_s] = "madda.s",
    [RABBITIZER_INSTR_ID_r5900_msuba_s] = "msuba.s",
    [RABBITIZER_INSTR_ID_r5900_max_s] = "max.s",
    [RABBITIZER_INSTR_ID_r5900_min_s] = "min.s",
    [RABBITIZER_INSTR_ID_r5900_c_lt_s] = "c.lt.s",
    [RABBITIZER_INSTR_ID_r5900_c_le_s] = "c.le.s",
    [RABBITIZER_INSTR_ID_r5900_qmfc2_ni] = "qmfc2.ni",
    [RABBITIZER_INSTR_ID_r5900_cfc2_ni] = "cfc2.ni",
    [RABBITIZER_INSTR_ID_r5900_qmtc2_ni] = "qmtc2.ni",
    [RABBITIZER_INSTR_ID_r5900_ctc2_ni] = "ctc2.ni",
    [RABBITIZER_INSTR_ID_r5900_qmfc2_i] = "qmfc2.i",
    [RABBITIZER_INSTR_ID_r5900_cfc2_i] = "cfc2.i",
    [RABBITIZER_INSTR_ID_r5900_qmtc2_i] = "qmtc2.i",
    [RABBITIZER_INSTR_ID_r5900_ctc2_i] = "ctc2.i",
    [RABBITIZER_INSTR_ID_r5900_bc2f] = "bc2f",
    [RABBITIZER_INSTR_ID_r5900_bc2t] = "bc2t",
    [RABBITIZER_INSTR_ID_r5900_bc2fl] = "bc2fl",
    [RABBITIZER_INSTR_ID_r5900_bc2tl] = "bc2tl",
    [RABBITIZER_INSTR_ID_r5900_vaddx] = "vaddx",
    [RABBITIZER_INSTR_ID_r5900_vaddy] = "vaddy",
    [RABBITIZER_INSTR_ID_r5900_vaddz] = "vaddz",
    [RABBITIZER_INSTR_ID_r5900_vaddw] = "vaddw",
    [RABBITIZER_INSTR_ID_r5900_vsubx] = "vsubx",
    [RABBITIZER_INSTR_ID_r5900_vsuby] = "vsuby",
    [RABBITIZER_INSTR_ID_r5900_vsubz] = "vsubz",
    [RABBITIZER_INSTR_ID_r5900_vsubw] = "vsubw",
    [RABBITIZER_INSTR_ID_r5900_vmaddx] = "vmaddx",
    [RABBITIZER_INSTR_ID_r5900_vmaddy] = "vmaddy",
    [RABBITIZER_INSTR_ID_r5900_vmaddz] = "vmaddz",
    [RABBITIZER_INSTR_ID_r5900_vmaddw] = "vmaddw",
    [RABBITIZER_INSTR_ID_r5900_vmsubx] = "vmsubx",
    [RABBITIZER_INSTR_ID_r5900_vmsuby] = "vmsuby",
    [RABBITIZER_INSTR_ID_r5900_vmsubz] = "vmsubz",
    [RABBITIZER_INSTR_ID_r5900_vmsubw] = "vmsubw",
    [RABBITIZER_INSTR_ID_r5900_vmaxx] = "vmaxx",
    [RABBITIZER_INSTR_ID_r5900_vmaxy] = "vmaxy",
    [RABBITIZER_INSTR_ID_r5900_vmaxz] = "vmaxz",
    [RABBITIZER_INSTR_ID_r5900_vmaxw] = "vmaxw",
    [RABBITIZER_INSTR_ID_r5900_vminix] = "vminix",
    [RABBITIZER_INSTR_ID_r5900_vminiy] = "vminiy",
    [RABBITIZER_INSTR_ID_r5900_vminiz] = "vminiz",
    [RABBITIZER_INSTR_ID_r5900_vminiw] = "vminiw",
    [RABBITIZER_INSTR_ID_r5900_vmulx] = "vmulx",
    [RABBITIZER_INSTR_ID_r5900_vmuly] = "vmuly",
    [RABBITIZER_INSTR_ID_r5900_vmulz] = "vmulz",
    [RABBITIZER_INSTR_ID_r5900_vmulw] = "vmulw",
    [RABBITIZER_INSTR_ID_r5900_vmulq] = "vmulq",
    [RABBITIZER_INSTR_ID_r5900_vmaxi] = "vmaxi",
    [RABBITIZER_INSTR_ID_r5900_vmuli] = "vmuli",
    [RABBITIZER_INSTR_ID_r5900_vminii] = "vminii",
    [RABBITIZER_INSTR_ID_r5900_vaddq] = "vaddq",
    [RABBITIZER_INSTR_ID_r5900_vmaddq] = "vmaddq",
    [RABBITIZER_INSTR_ID_r5900_vaddi] = "vaddi",
    [RABBITIZER_INSTR_ID_r5900_vmaddi] = "vmaddi",
    [RABBITIZER_INSTR_ID_r5900_vsubq] = "vsubq",
    [RABBITIZER_INSTR_ID_r5900_vmsubq] = "vmsubq",
    [RABBITIZER_INSTR_ID_r5900_vsubi] = "vsubi",
    [RABBITIZER_INSTR_ID_r5900_vmsubi] = "vmsubi",
    [RABBITIZER_INSTR_ID_r5900_vadd] = "vadd",
    [RABBITIZER_INSTR_ID_r5900_vmadd] = "vmadd",
    [RABBITIZER_INSTR_ID_r5900_vmul] = "vmul",
    [RABBITIZER_INSTR_ID_r5900_vmax] = "vmax",
    [RABBITIZER_INSTR_ID_r5900_vsub] = "vsub",
    [RABBITIZER_INSTR_ID_r5900_vmsub] = "vmsub",
    [RABBITIZER_INSTR_ID_r5900_vopmsub] = "vopmsub",
    [RABBITIZER_INSTR_ID_r5900_vmini] = "vmini",
    [RABBITIZER_INSTR_ID_r5900_viadd] = "viadd",
    [RABBITIZER_INSTR_ID_r5900_visub] = "visub",
    [RABBITIZER_INSTR_ID_r5900_viaddi] = "viaddi",
    [RABBITIZER_INSTR_ID_r5900_viand] = "viand",
    [RABBITIZER_INSTR_ID_r5900_vior] = "vior",
    [RABBITIZER_INSTR_ID_r5900_vcallms] = "vcallms",
    [RABBITIZER_INSTR_ID_r5900_vcallmsr] = "vcallmsr",
    [RABBITIZER_INSTR_ID_r5900_vaddax] = "vaddax",
    [RABBITIZER_INSTR_ID_r5900_vadday] = "vadday",
    [RABBITIZER_INSTR_ID_r5900_vaddaz] = "vaddaz",
    [RABBITIZER_INSTR_ID_r5900_vaddaw] = "vaddaw",
    [RABBITIZER_INSTR_ID_r5900_vsubax] = "vsubax",
    [RABBITIZER_INSTR_ID_r5900_vsubay] = "vsubay",
    [RABBITIZER_INSTR_ID_r5900_vsubaz] = "vsubaz",
    [RABBITIZER_INSTR_ID_r5900_vsubaw] = "vsubaw",
    [RABBITIZER_INSTR_ID_r5900_vmaddax] = "vmaddax",
    [RABBITIZER_INSTR_ID_r5900_vmadday] = "vmadday",
    [RABBITIZER_INSTR_ID_r5900_vmaddaz] = "vmaddaz",
    [RABBITIZER_INSTR_ID_r5900_vmaddaw] = "vmaddaw",
    [RABBITIZER_INSTR_ID_r5900_vmsubax] = "vmsubax",
    [RABBITIZER_INSTR_ID_r5900_vmsubay] = "vmsubay",
    [RABBITIZER_INSTR_ID_r5900_vmsubaz] = "vmsubaz",
    [RABBITIZER_INSTR_ID_r5900_vmsubaw] = "vmsubaw",
    [RABBITIZER_INSTR_ID_r5900_vitof0] = "vitof0",
    [RABBITIZER_INSTR_ID_r5900_vitof4] = "vitof4",
    [RABBITIZER_INSTR_ID_r5900_vitof12] = "vitof12",
    [RABBITIZER_INSTR_ID_r5900_vitof15] = "vitof15",
    [RABBITIZER_INSTR_ID_r5900_vftoi0] = "vftoi0",
    [RABBITIZER_INSTR_ID_r5900_vftoi4] = "vftoi4",
    [RABBITIZER_INSTR_ID_r5900_vftoi12] = "vftoi12",
    [RABBITIZER_INSTR_ID_r5900_vftoi15] = "vftoi15",
    [RABBITIZER_INSTR_ID_r5900_vmulax] = "vmulax",
    [RABBITIZER_INSTR_ID_r5900_vmulay] = "vmulay",
    [RABBITIZER_INSTR_ID_r5900_vmulaz] = "vmulaz",
    [RABBITIZER_INSTR_ID_r5900_vmulaw] = "vmulaw",
    [RABBITIZER_INSTR_ID_r5900_vmulaq] = "vmulaq",
    [RABBITIZER_INSTR_ID_r5900_vabs] = "vabs",
    [RABBITIZER_INSTR_ID_r5900_vmulai] = "vmulai",
    [RABBITIZER_INSTR_ID_r5900_vclipw] = "vclipw",
    [RABBITIZER_INSTR_ID_r5900_vaddaq] = "vaddaq",
    [RABBITIZER_INSTR_ID_r5900_vmaddaq] = "vmaddaq",
    [RABBITIZER_INSTR_ID_r5900_vaddai] = "vaddai",
    [RABBITIZER_INSTR_ID_r5900_vmaddai] = "vmaddai",
    [RABBITIZER_INSTR_ID_r5900_vsubaq] = "vsubaq",
    [RABBITIZER_INSTR_ID_r5900_vmsubaq] = "vmsubaq",
    [RABBITIZER_INSTR_ID_r5900_vsubai] = "vsubai",
    [RABBITIZER_INSTR_ID_r5900_vmsubai] = "vmsubai",
    [RABBITIZER_INSTR_ID_r5900_vadda] = "vadda",
    [RABBITIZER_INSTR_ID_r5900_vmadda] = "vmadda",
    [RABBITIZER_INSTR_ID_r5900_vmula] = "vmula",
    [RABBITIZER_INSTR_ID_r5900_vsuba] = "vsuba",
    [RABBITIZER_INSTR_ID_r5900_vmsuba] = "vmsuba",
    [RABBITIZER_INSTR_ID_r5900_vopmula] = "vopmula",
    [RABBITIZER_INSTR_ID_r5900_vnop] = "vnop",
    [RABBITIZER_INSTR_ID_r5900_vmove] = "vmove",
    [RABBITIZER_INSTR_ID_r5900_vmr32] = "vmr32",
    [RABBITIZER_INSTR_ID_r5900_vlqi] = "vlqi",
    [RABBITIZER_INSTR_ID_r5900_vsqi] = "vsqi",
    [RABBITIZER_INSTR_ID_r5900_vlqd] = "vlqd",
    [RABBITIZER_INSTR_ID_r5900_vsqd] = "vsqd",
    [RABBITIZER_INSTR_ID_r5900_vdiv] = "vdiv",
    [RABBITIZER_INSTR_ID_r5900_vsqrt] = "vsqrt",
    [RABBITIZER_INSTR_ID_r5900_vrsqrt] = "vrsqrt",
    [RABBITIZER_INSTR_ID_r5900_vwaitq] = "vwaitq",
    [RABBITIZER_INSTR_ID_r5900_vmtir] = "vmtir",
    [RABBITIZER_INSTR_ID_r5900_vmfir] = "vmfir",
    [RABBITIZER_INSTR_ID_r5900_vrnext] = "vrnext",
    [RABBITIZER_INSTR_ID_r5900_vrget] = "vrget",
    [RABBITIZER_INSTR_ID_r5900_vrinit] = "vrinit",
    [RABBITIZER_INSTR_ID_r5900_vrxor] = "vrxor",
    [RABBITIZER_INSTR_ID_r5900_vilwr_w] = "vilwr.w",
    [RABBITIZER_INSTR_ID_r5900_vilwr_z] = "vilwr.z",
    [RABBITIZER_INSTR_ID_r5900_vilwr_y] = "vilwr.y",
    [RABBITIZER_INSTR_ID_r5900_vilwr_x] = "vilwr.x",
    [RABBITIZER_INSTR_ID_r5900_viswr_w] = "viswr.w",
    [RABBITIZER_INSTR_ID_r5900_viswr_z] = "viswr.z",
    [RABBITIZER_INSTR_ID_r5900_viswr_y] = "viswr.y",
    [RABBITIZER_INSTR_ID_r5900_viswr_x] = "viswr.x",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_00] = "USERDEF_00",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_01] = "USERDEF_01",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_02] = "USERDEF_02",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_03] = "USERDEF_03",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_04] = "USERDEF_04",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_05] = "USERDEF_05",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_06] = "USERDEF_06",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_07] = "USERDEF_07",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_08] = "USERDEF_08",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_09] = "USERDEF_09",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_10] = "USERDEF_10",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_11] = "USERDEF_11",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_12] = "USERDEF_12",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_13] = "USERDEF_13",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_14] = "USERDEF_14",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_15] = "USERDEF_15",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_16] = "USERDEF_16",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_17] = "USERDEF_17",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_18] = "USERDEF_18",
    [RABBITIZER_INSTR_ID_r5900_USERDEF_19] = "USERDEF_19",
    [RABBITIZER_INSTR_ID_r5900_MAX] = "MAX",
};

#endif
