/* SPDX-FileCopyrightText: © 2022-2024 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef Registers_enums_h_automatic
#define Registers_enums_h_automatic

typedef enum RabbitizerRegister_GprO32 {
    RABBITIZER_REG_GPR_O32_zero,
    RABBITIZER_REG_GPR_O32_at,
    RABBITIZER_REG_GPR_O32_v0,
    RABBITIZER_REG_GPR_O32_v1,
    RABBITIZER_REG_GPR_O32_a0,
    RABBITIZER_REG_GPR_O32_a1,
    RABBITIZER_REG_GPR_O32_a2,
    RABBITIZER_REG_GPR_O32_a3,
    RABBITIZER_REG_GPR_O32_t0,
    RABBITIZER_REG_GPR_O32_t1,
    RABBITIZER_REG_GPR_O32_t2,
    RABBITIZER_REG_GPR_O32_t3,
    RABBITIZER_REG_GPR_O32_t4,
    RABBITIZER_REG_GPR_O32_t5,
    RABBITIZER_REG_GPR_O32_t6,
    RABBITIZER_REG_GPR_O32_t7,
    RABBITIZER_REG_GPR_O32_s0,
    RABBITIZER_REG_GPR_O32_s1,
    RABBITIZER_REG_GPR_O32_s2,
    RABBITIZER_REG_GPR_O32_s3,
    RABBITIZER_REG_GPR_O32_s4,
    RABBITIZER_REG_GPR_O32_s5,
    RABBITIZER_REG_GPR_O32_s6,
    RABBITIZER_REG_GPR_O32_s7,
    RABBITIZER_REG_GPR_O32_t8,
    RABBITIZER_REG_GPR_O32_t9,
    RABBITIZER_REG_GPR_O32_k0,
    RABBITIZER_REG_GPR_O32_k1,
    RABBITIZER_REG_GPR_O32_gp,
    RABBITIZER_REG_GPR_O32_sp,
    RABBITIZER_REG_GPR_O32_fp,
    RABBITIZER_REG_GPR_O32_ra,
} RabbitizerRegister_GprO32;
typedef enum RabbitizerRegister_GprN32 {
    RABBITIZER_REG_GPR_N32_zero,
    RABBITIZER_REG_GPR_N32_at,
    RABBITIZER_REG_GPR_N32_v0,
    RABBITIZER_REG_GPR_N32_v1,
    RABBITIZER_REG_GPR_N32_a0,
    RABBITIZER_REG_GPR_N32_a1,
    RABBITIZER_REG_GPR_N32_a2,
    RABBITIZER_REG_GPR_N32_a3,
    RABBITIZER_REG_GPR_N32_a4,
    RABBITIZER_REG_GPR_N32_a5,
    RABBITIZER_REG_GPR_N32_a6,
    RABBITIZER_REG_GPR_N32_a7,
    RABBITIZER_REG_GPR_N32_t0,
    RABBITIZER_REG_GPR_N32_t1,
    RABBITIZER_REG_GPR_N32_t2,
    RABBITIZER_REG_GPR_N32_t3,
    RABBITIZER_REG_GPR_N32_s0,
    RABBITIZER_REG_GPR_N32_s1,
    RABBITIZER_REG_GPR_N32_s2,
    RABBITIZER_REG_GPR_N32_s3,
    RABBITIZER_REG_GPR_N32_s4,
    RABBITIZER_REG_GPR_N32_s5,
    RABBITIZER_REG_GPR_N32_s6,
    RABBITIZER_REG_GPR_N32_s7,
    RABBITIZER_REG_GPR_N32_t8,
    RABBITIZER_REG_GPR_N32_t9,
    RABBITIZER_REG_GPR_N32_k0,
    RABBITIZER_REG_GPR_N32_k1,
    RABBITIZER_REG_GPR_N32_gp,
    RABBITIZER_REG_GPR_N32_sp,
    RABBITIZER_REG_GPR_N32_fp,
    RABBITIZER_REG_GPR_N32_ra,
} RabbitizerRegister_GprN32;
typedef enum RabbitizerRegister_Cop0 {
    RABBITIZER_REG_COP0_Index,
    RABBITIZER_REG_COP0_Random,
    RABBITIZER_REG_COP0_EntryLo0,
    RABBITIZER_REG_COP0_EntryLo1,
    RABBITIZER_REG_COP0_Context,
    RABBITIZER_REG_COP0_PageMask,
    RABBITIZER_REG_COP0_Wired,
    RABBITIZER_REG_COP0_Reserved07,
    RABBITIZER_REG_COP0_BadVaddr,
    RABBITIZER_REG_COP0_Count,
    RABBITIZER_REG_COP0_EntryHi,
    RABBITIZER_REG_COP0_Compare,
    RABBITIZER_REG_COP0_Status,
    RABBITIZER_REG_COP0_Cause,
    RABBITIZER_REG_COP0_EPC,
    RABBITIZER_REG_COP0_PRevID,
    RABBITIZER_REG_COP0_Config,
    RABBITIZER_REG_COP0_LLAddr,
    RABBITIZER_REG_COP0_WatchLo,
    RABBITIZER_REG_COP0_WatchHi,
    RABBITIZER_REG_COP0_XContext,
    RABBITIZER_REG_COP0_Reserved21,
    RABBITIZER_REG_COP0_Reserved22,
    RABBITIZER_REG_COP0_Reserved23,
    RABBITIZER_REG_COP0_Reserved24,
    RABBITIZER_REG_COP0_Reserved25,
    RABBITIZER_REG_COP0_PErr,
    RABBITIZER_REG_COP0_CacheErr,
    RABBITIZER_REG_COP0_TagLo,
    RABBITIZER_REG_COP0_TagHi,
    RABBITIZER_REG_COP0_ErrorEPC,
    RABBITIZER_REG_COP0_Reserved31,
} RabbitizerRegister_Cop0;
typedef enum RabbitizerRegister_Cop1O32 {
    RABBITIZER_REG_COP1_O32_fv0,
    RABBITIZER_REG_COP1_O32_fv0f,
    RABBITIZER_REG_COP1_O32_fv1,
    RABBITIZER_REG_COP1_O32_fv1f,
    RABBITIZER_REG_COP1_O32_ft0,
    RABBITIZER_REG_COP1_O32_ft0f,
    RABBITIZER_REG_COP1_O32_ft1,
    RABBITIZER_REG_COP1_O32_ft1f,
    RABBITIZER_REG_COP1_O32_ft2,
    RABBITIZER_REG_COP1_O32_ft2f,
    RABBITIZER_REG_COP1_O32_ft3,
    RABBITIZER_REG_COP1_O32_ft3f,
    RABBITIZER_REG_COP1_O32_fa0,
    RABBITIZER_REG_COP1_O32_fa0f,
    RABBITIZER_REG_COP1_O32_fa1,
    RABBITIZER_REG_COP1_O32_fa1f,
    RABBITIZER_REG_COP1_O32_ft4,
    RABBITIZER_REG_COP1_O32_ft4f,
    RABBITIZER_REG_COP1_O32_ft5,
    RABBITIZER_REG_COP1_O32_ft5f,
    RABBITIZER_REG_COP1_O32_fs0,
    RABBITIZER_REG_COP1_O32_fs0f,
    RABBITIZER_REG_COP1_O32_fs1,
    RABBITIZER_REG_COP1_O32_fs1f,
    RABBITIZER_REG_COP1_O32_fs2,
    RABBITIZER_REG_COP1_O32_fs2f,
    RABBITIZER_REG_COP1_O32_fs3,
    RABBITIZER_REG_COP1_O32_fs3f,
    RABBITIZER_REG_COP1_O32_fs4,
    RABBITIZER_REG_COP1_O32_fs4f,
    RABBITIZER_REG_COP1_O32_fs5,
    RABBITIZER_REG_COP1_O32_fs5f,
} RabbitizerRegister_Cop1O32;
typedef enum RabbitizerRegister_Cop1N32 {
    RABBITIZER_REG_COP1_N32_fv0,
    RABBITIZER_REG_COP1_N32_ft14,
    RABBITIZER_REG_COP1_N32_fv1,
    RABBITIZER_REG_COP1_N32_ft15,
    RABBITIZER_REG_COP1_N32_ft0,
    RABBITIZER_REG_COP1_N32_ft1,
    RABBITIZER_REG_COP1_N32_ft2,
    RABBITIZER_REG_COP1_N32_ft3,
    RABBITIZER_REG_COP1_N32_ft4,
    RABBITIZER_REG_COP1_N32_ft5,
    RABBITIZER_REG_COP1_N32_ft6,
    RABBITIZER_REG_COP1_N32_ft7,
    RABBITIZER_REG_COP1_N32_fa0,
    RABBITIZER_REG_COP1_N32_fa1,
    RABBITIZER_REG_COP1_N32_fa2,
    RABBITIZER_REG_COP1_N32_fa3,
    RABBITIZER_REG_COP1_N32_fa4,
    RABBITIZER_REG_COP1_N32_fa5,
    RABBITIZER_REG_COP1_N32_fa6,
    RABBITIZER_REG_COP1_N32_fa7,
    RABBITIZER_REG_COP1_N32_fs0,
    RABBITIZER_REG_COP1_N32_ft8,
    RABBITIZER_REG_COP1_N32_fs1,
    RABBITIZER_REG_COP1_N32_ft9,
    RABBITIZER_REG_COP1_N32_fs2,
    RABBITIZER_REG_COP1_N32_ft10,
    RABBITIZER_REG_COP1_N32_fs3,
    RABBITIZER_REG_COP1_N32_ft11,
    RABBITIZER_REG_COP1_N32_fs4,
    RABBITIZER_REG_COP1_N32_ft12,
    RABBITIZER_REG_COP1_N32_fs5,
    RABBITIZER_REG_COP1_N32_ft13,
} RabbitizerRegister_Cop1N32;
typedef enum RabbitizerRegister_Cop1N64 {
    RABBITIZER_REG_COP1_N64_fv0,
    RABBITIZER_REG_COP1_N64_ft12,
    RABBITIZER_REG_COP1_N64_fv1,
    RABBITIZER_REG_COP1_N64_ft13,
    RABBITIZER_REG_COP1_N64_ft0,
    RABBITIZER_REG_COP1_N64_ft1,
    RABBITIZER_REG_COP1_N64_ft2,
    RABBITIZER_REG_COP1_N64_ft3,
    RABBITIZER_REG_COP1_N64_ft4,
    RABBITIZER_REG_COP1_N64_ft5,
    RABBITIZER_REG_COP1_N64_ft6,
    RABBITIZER_REG_COP1_N64_ft7,
    RABBITIZER_REG_COP1_N64_fa0,
    RABBITIZER_REG_COP1_N64_fa1,
    RABBITIZER_REG_COP1_N64_fa2,
    RABBITIZER_REG_COP1_N64_fa3,
    RABBITIZER_REG_COP1_N64_fa4,
    RABBITIZER_REG_COP1_N64_fa5,
    RABBITIZER_REG_COP1_N64_fa6,
    RABBITIZER_REG_COP1_N64_fa7,
    RABBITIZER_REG_COP1_N64_ft8,
    RABBITIZER_REG_COP1_N64_ft9,
    RABBITIZER_REG_COP1_N64_ft10,
    RABBITIZER_REG_COP1_N64_ft11,
    RABBITIZER_REG_COP1_N64_fs0,
    RABBITIZER_REG_COP1_N64_fs1,
    RABBITIZER_REG_COP1_N64_fs2,
    RABBITIZER_REG_COP1_N64_fs3,
    RABBITIZER_REG_COP1_N64_fs4,
    RABBITIZER_REG_COP1_N64_fs5,
    RABBITIZER_REG_COP1_N64_fs6,
    RABBITIZER_REG_COP1_N64_fs7,
} RabbitizerRegister_Cop1N64;
typedef enum RabbitizerRegister_Cop1Control {
    RABBITIZER_REG_COP1_CONTROL_0,
    RABBITIZER_REG_COP1_CONTROL_1,
    RABBITIZER_REG_COP1_CONTROL_2,
    RABBITIZER_REG_COP1_CONTROL_3,
    RABBITIZER_REG_COP1_CONTROL_4,
    RABBITIZER_REG_COP1_CONTROL_5,
    RABBITIZER_REG_COP1_CONTROL_6,
    RABBITIZER_REG_COP1_CONTROL_7,
    RABBITIZER_REG_COP1_CONTROL_8,
    RABBITIZER_REG_COP1_CONTROL_9,
    RABBITIZER_REG_COP1_CONTROL_10,
    RABBITIZER_REG_COP1_CONTROL_11,
    RABBITIZER_REG_COP1_CONTROL_12,
    RABBITIZER_REG_COP1_CONTROL_13,
    RABBITIZER_REG_COP1_CONTROL_14,
    RABBITIZER_REG_COP1_CONTROL_15,
    RABBITIZER_REG_COP1_CONTROL_16,
    RABBITIZER_REG_COP1_CONTROL_17,
    RABBITIZER_REG_COP1_CONTROL_18,
    RABBITIZER_REG_COP1_CONTROL_19,
    RABBITIZER_REG_COP1_CONTROL_20,
    RABBITIZER_REG_COP1_CONTROL_21,
    RABBITIZER_REG_COP1_CONTROL_22,
    RABBITIZER_REG_COP1_CONTROL_23,
    RABBITIZER_REG_COP1_CONTROL_24,
    RABBITIZER_REG_COP1_CONTROL_25,
    RABBITIZER_REG_COP1_CONTROL_26,
    RABBITIZER_REG_COP1_CONTROL_27,
    RABBITIZER_REG_COP1_CONTROL_28,
    RABBITIZER_REG_COP1_CONTROL_29,
    RABBITIZER_REG_COP1_CONTROL_30,
    RABBITIZER_REG_COP1_CONTROL_FpcCsr,
} RabbitizerRegister_Cop1Control;
typedef enum RabbitizerRegister_Cop2 {
    RABBITIZER_REG_COP2_0,
    RABBITIZER_REG_COP2_1,
    RABBITIZER_REG_COP2_2,
    RABBITIZER_REG_COP2_3,
    RABBITIZER_REG_COP2_4,
    RABBITIZER_REG_COP2_5,
    RABBITIZER_REG_COP2_6,
    RABBITIZER_REG_COP2_7,
    RABBITIZER_REG_COP2_8,
    RABBITIZER_REG_COP2_9,
    RABBITIZER_REG_COP2_10,
    RABBITIZER_REG_COP2_11,
    RABBITIZER_REG_COP2_12,
    RABBITIZER_REG_COP2_13,
    RABBITIZER_REG_COP2_14,
    RABBITIZER_REG_COP2_15,
    RABBITIZER_REG_COP2_16,
    RABBITIZER_REG_COP2_17,
    RABBITIZER_REG_COP2_18,
    RABBITIZER_REG_COP2_19,
    RABBITIZER_REG_COP2_20,
    RABBITIZER_REG_COP2_21,
    RABBITIZER_REG_COP2_22,
    RABBITIZER_REG_COP2_23,
    RABBITIZER_REG_COP2_24,
    RABBITIZER_REG_COP2_25,
    RABBITIZER_REG_COP2_26,
    RABBITIZER_REG_COP2_27,
    RABBITIZER_REG_COP2_28,
    RABBITIZER_REG_COP2_29,
    RABBITIZER_REG_COP2_30,
    RABBITIZER_REG_COP2_31,
} RabbitizerRegister_Cop2;
typedef enum RabbitizerRegister_RspGpr {
    RABBITIZER_REG_RSP_GPR_zero,
    RABBITIZER_REG_RSP_GPR_1,
    RABBITIZER_REG_RSP_GPR_2,
    RABBITIZER_REG_RSP_GPR_3,
    RABBITIZER_REG_RSP_GPR_4,
    RABBITIZER_REG_RSP_GPR_5,
    RABBITIZER_REG_RSP_GPR_6,
    RABBITIZER_REG_RSP_GPR_7,
    RABBITIZER_REG_RSP_GPR_8,
    RABBITIZER_REG_RSP_GPR_9,
    RABBITIZER_REG_RSP_GPR_10,
    RABBITIZER_REG_RSP_GPR_11,
    RABBITIZER_REG_RSP_GPR_12,
    RABBITIZER_REG_RSP_GPR_13,
    RABBITIZER_REG_RSP_GPR_14,
    RABBITIZER_REG_RSP_GPR_15,
    RABBITIZER_REG_RSP_GPR_16,
    RABBITIZER_REG_RSP_GPR_17,
    RABBITIZER_REG_RSP_GPR_18,
    RABBITIZER_REG_RSP_GPR_19,
    RABBITIZER_REG_RSP_GPR_20,
    RABBITIZER_REG_RSP_GPR_21,
    RABBITIZER_REG_RSP_GPR_22,
    RABBITIZER_REG_RSP_GPR_23,
    RABBITIZER_REG_RSP_GPR_24,
    RABBITIZER_REG_RSP_GPR_25,
    RABBITIZER_REG_RSP_GPR_26,
    RABBITIZER_REG_RSP_GPR_27,
    RABBITIZER_REG_RSP_GPR_28,
    RABBITIZER_REG_RSP_GPR_29,
    RABBITIZER_REG_RSP_GPR_30,
    RABBITIZER_REG_RSP_GPR_ra,
} RabbitizerRegister_RspGpr;
typedef enum RabbitizerRegister_RspCop0 {
    RABBITIZER_REG_RSP_COP0_SP_MEM_ADDR,
    RABBITIZER_REG_RSP_COP0_SP_DRAM_ADDR,
    RABBITIZER_REG_RSP_COP0_SP_RD_LEN,
    RABBITIZER_REG_RSP_COP0_SP_WR_LEN,
    RABBITIZER_REG_RSP_COP0_SP_STATUS,
    RABBITIZER_REG_RSP_COP0_SP_DMA_FULL,
    RABBITIZER_REG_RSP_COP0_SP_DMA_BUSY,
    RABBITIZER_REG_RSP_COP0_SP_SEMAPHORE,
    RABBITIZER_REG_RSP_COP0_DPC_START,
    RABBITIZER_REG_RSP_COP0_DPC_END,
    RABBITIZER_REG_RSP_COP0_DPC_CURRENT,
    RABBITIZER_REG_RSP_COP0_DPC_STATUS,
    RABBITIZER_REG_RSP_COP0_DPC_CLOCK,
    RABBITIZER_REG_RSP_COP0_DPC_BUFBUSY,
    RABBITIZER_REG_RSP_COP0_DPC_PIPEBUSY,
    RABBITIZER_REG_RSP_COP0_DPC_TMEM,
} RabbitizerRegister_RspCop0;
typedef enum RabbitizerRegister_RspCop2 {
    RABBITIZER_REG_RSP_COP2_0,
    RABBITIZER_REG_RSP_COP2_1,
    RABBITIZER_REG_RSP_COP2_2,
    RABBITIZER_REG_RSP_COP2_3,
    RABBITIZER_REG_RSP_COP2_4,
    RABBITIZER_REG_RSP_COP2_5,
    RABBITIZER_REG_RSP_COP2_6,
    RABBITIZER_REG_RSP_COP2_7,
    RABBITIZER_REG_RSP_COP2_8,
    RABBITIZER_REG_RSP_COP2_9,
    RABBITIZER_REG_RSP_COP2_10,
    RABBITIZER_REG_RSP_COP2_11,
    RABBITIZER_REG_RSP_COP2_12,
    RABBITIZER_REG_RSP_COP2_13,
    RABBITIZER_REG_RSP_COP2_14,
    RABBITIZER_REG_RSP_COP2_15,
    RABBITIZER_REG_RSP_COP2_16,
    RABBITIZER_REG_RSP_COP2_17,
    RABBITIZER_REG_RSP_COP2_18,
    RABBITIZER_REG_RSP_COP2_19,
    RABBITIZER_REG_RSP_COP2_20,
    RABBITIZER_REG_RSP_COP2_21,
    RABBITIZER_REG_RSP_COP2_22,
    RABBITIZER_REG_RSP_COP2_23,
    RABBITIZER_REG_RSP_COP2_24,
    RABBITIZER_REG_RSP_COP2_25,
    RABBITIZER_REG_RSP_COP2_26,
    RABBITIZER_REG_RSP_COP2_27,
    RABBITIZER_REG_RSP_COP2_28,
    RABBITIZER_REG_RSP_COP2_29,
    RABBITIZER_REG_RSP_COP2_30,
    RABBITIZER_REG_RSP_COP2_31,
} RabbitizerRegister_RspCop2;
typedef enum RabbitizerRegister_RspCop2Control {
    RABBITIZER_REG_RSP_COP2_CONTROL_0,
    RABBITIZER_REG_RSP_COP2_CONTROL_1,
    RABBITIZER_REG_RSP_COP2_CONTROL_2,
    RABBITIZER_REG_RSP_COP2_CONTROL_3,
    RABBITIZER_REG_RSP_COP2_CONTROL_4,
    RABBITIZER_REG_RSP_COP2_CONTROL_5,
    RABBITIZER_REG_RSP_COP2_CONTROL_6,
    RABBITIZER_REG_RSP_COP2_CONTROL_7,
    RABBITIZER_REG_RSP_COP2_CONTROL_8,
    RABBITIZER_REG_RSP_COP2_CONTROL_9,
    RABBITIZER_REG_RSP_COP2_CONTROL_10,
    RABBITIZER_REG_RSP_COP2_CONTROL_11,
    RABBITIZER_REG_RSP_COP2_CONTROL_12,
    RABBITIZER_REG_RSP_COP2_CONTROL_13,
    RABBITIZER_REG_RSP_COP2_CONTROL_14,
    RABBITIZER_REG_RSP_COP2_CONTROL_15,
    RABBITIZER_REG_RSP_COP2_CONTROL_16,
    RABBITIZER_REG_RSP_COP2_CONTROL_17,
    RABBITIZER_REG_RSP_COP2_CONTROL_18,
    RABBITIZER_REG_RSP_COP2_CONTROL_19,
    RABBITIZER_REG_RSP_COP2_CONTROL_20,
    RABBITIZER_REG_RSP_COP2_CONTROL_21,
    RABBITIZER_REG_RSP_COP2_CONTROL_22,
    RABBITIZER_REG_RSP_COP2_CONTROL_23,
    RABBITIZER_REG_RSP_COP2_CONTROL_24,
    RABBITIZER_REG_RSP_COP2_CONTROL_25,
    RABBITIZER_REG_RSP_COP2_CONTROL_26,
    RABBITIZER_REG_RSP_COP2_CONTROL_27,
    RABBITIZER_REG_RSP_COP2_CONTROL_28,
    RABBITIZER_REG_RSP_COP2_CONTROL_29,
    RABBITIZER_REG_RSP_COP2_CONTROL_30,
    RABBITIZER_REG_RSP_COP2_CONTROL_31,
} RabbitizerRegister_RspCop2Control;
typedef enum RabbitizerRegister_RspVector {
    RABBITIZER_REG_RSP_VECTOR_v0,
    RABBITIZER_REG_RSP_VECTOR_v1,
    RABBITIZER_REG_RSP_VECTOR_v2,
    RABBITIZER_REG_RSP_VECTOR_v3,
    RABBITIZER_REG_RSP_VECTOR_v4,
    RABBITIZER_REG_RSP_VECTOR_v5,
    RABBITIZER_REG_RSP_VECTOR_v6,
    RABBITIZER_REG_RSP_VECTOR_v7,
    RABBITIZER_REG_RSP_VECTOR_v8,
    RABBITIZER_REG_RSP_VECTOR_v9,
    RABBITIZER_REG_RSP_VECTOR_v10,
    RABBITIZER_REG_RSP_VECTOR_v11,
    RABBITIZER_REG_RSP_VECTOR_v12,
    RABBITIZER_REG_RSP_VECTOR_v13,
    RABBITIZER_REG_RSP_VECTOR_v14,
    RABBITIZER_REG_RSP_VECTOR_v15,
    RABBITIZER_REG_RSP_VECTOR_v16,
    RABBITIZER_REG_RSP_VECTOR_v17,
    RABBITIZER_REG_RSP_VECTOR_v18,
    RABBITIZER_REG_RSP_VECTOR_v19,
    RABBITIZER_REG_RSP_VECTOR_v20,
    RABBITIZER_REG_RSP_VECTOR_v21,
    RABBITIZER_REG_RSP_VECTOR_v22,
    RABBITIZER_REG_RSP_VECTOR_v23,
    RABBITIZER_REG_RSP_VECTOR_v24,
    RABBITIZER_REG_RSP_VECTOR_v25,
    RABBITIZER_REG_RSP_VECTOR_v26,
    RABBITIZER_REG_RSP_VECTOR_v27,
    RABBITIZER_REG_RSP_VECTOR_v28,
    RABBITIZER_REG_RSP_VECTOR_v29,
    RABBITIZER_REG_RSP_VECTOR_v30,
    RABBITIZER_REG_RSP_VECTOR_v31,
} RabbitizerRegister_RspVector;
typedef enum RabbitizerRegister_R4000AllegrexS {
    RABBITIZER_REG_R4000ALLEGREX_S_S000,
    RABBITIZER_REG_R4000ALLEGREX_S_S010,
    RABBITIZER_REG_R4000ALLEGREX_S_S020,
    RABBITIZER_REG_R4000ALLEGREX_S_S030,
    RABBITIZER_REG_R4000ALLEGREX_S_S100,
    RABBITIZER_REG_R4000ALLEGREX_S_S110,
    RABBITIZER_REG_R4000ALLEGREX_S_S120,
    RABBITIZER_REG_R4000ALLEGREX_S_S130,
    RABBITIZER_REG_R4000ALLEGREX_S_S200,
    RABBITIZER_REG_R4000ALLEGREX_S_S210,
    RABBITIZER_REG_R4000ALLEGREX_S_S220,
    RABBITIZER_REG_R4000ALLEGREX_S_S230,
    RABBITIZER_REG_R4000ALLEGREX_S_S300,
    RABBITIZER_REG_R4000ALLEGREX_S_S310,
    RABBITIZER_REG_R4000ALLEGREX_S_S320,
    RABBITIZER_REG_R4000ALLEGREX_S_S330,
    RABBITIZER_REG_R4000ALLEGREX_S_S400,
    RABBITIZER_REG_R4000ALLEGREX_S_S410,
    RABBITIZER_REG_R4000ALLEGREX_S_S420,
    RABBITIZER_REG_R4000ALLEGREX_S_S430,
    RABBITIZER_REG_R4000ALLEGREX_S_S500,
    RABBITIZER_REG_R4000ALLEGREX_S_S510,
    RABBITIZER_REG_R4000ALLEGREX_S_S520,
    RABBITIZER_REG_R4000ALLEGREX_S_S530,
    RABBITIZER_REG_R4000ALLEGREX_S_S600,
    RABBITIZER_REG_R4000ALLEGREX_S_S610,
    RABBITIZER_REG_R4000ALLEGREX_S_S620,
    RABBITIZER_REG_R4000ALLEGREX_S_S630,
    RABBITIZER_REG_R4000ALLEGREX_S_S700,
    RABBITIZER_REG_R4000ALLEGREX_S_S710,
    RABBITIZER_REG_R4000ALLEGREX_S_S720,
    RABBITIZER_REG_R4000ALLEGREX_S_S730,
    RABBITIZER_REG_R4000ALLEGREX_S_S001,
    RABBITIZER_REG_R4000ALLEGREX_S_S011,
    RABBITIZER_REG_R4000ALLEGREX_S_S021,
    RABBITIZER_REG_R4000ALLEGREX_S_S031,
    RABBITIZER_REG_R4000ALLEGREX_S_S101,
    RABBITIZER_REG_R4000ALLEGREX_S_S111,
    RABBITIZER_REG_R4000ALLEGREX_S_S121,
    RABBITIZER_REG_R4000ALLEGREX_S_S131,
    RABBITIZER_REG_R4000ALLEGREX_S_S201,
    RABBITIZER_REG_R4000ALLEGREX_S_S211,
    RABBITIZER_REG_R4000ALLEGREX_S_S221,
    RABBITIZER_REG_R4000ALLEGREX_S_S231,
    RABBITIZER_REG_R4000ALLEGREX_S_S301,
    RABBITIZER_REG_R4000ALLEGREX_S_S311,
    RABBITIZER_REG_R4000ALLEGREX_S_S321,
    RABBITIZER_REG_R4000ALLEGREX_S_S331,
    RABBITIZER_REG_R4000ALLEGREX_S_S401,
    RABBITIZER_REG_R4000ALLEGREX_S_S411,
    RABBITIZER_REG_R4000ALLEGREX_S_S421,
    RABBITIZER_REG_R4000ALLEGREX_S_S431,
    RABBITIZER_REG_R4000ALLEGREX_S_S501,
    RABBITIZER_REG_R4000ALLEGREX_S_S511,
    RABBITIZER_REG_R4000ALLEGREX_S_S521,
    RABBITIZER_REG_R4000ALLEGREX_S_S531,
    RABBITIZER_REG_R4000ALLEGREX_S_S601,
    RABBITIZER_REG_R4000ALLEGREX_S_S611,
    RABBITIZER_REG_R4000ALLEGREX_S_S621,
    RABBITIZER_REG_R4000ALLEGREX_S_S631,
    RABBITIZER_REG_R4000ALLEGREX_S_S701,
    RABBITIZER_REG_R4000ALLEGREX_S_S711,
    RABBITIZER_REG_R4000ALLEGREX_S_S721,
    RABBITIZER_REG_R4000ALLEGREX_S_S731,
    RABBITIZER_REG_R4000ALLEGREX_S_S002,
    RABBITIZER_REG_R4000ALLEGREX_S_S012,
    RABBITIZER_REG_R4000ALLEGREX_S_S022,
    RABBITIZER_REG_R4000ALLEGREX_S_S032,
    RABBITIZER_REG_R4000ALLEGREX_S_S102,
    RABBITIZER_REG_R4000ALLEGREX_S_S112,
    RABBITIZER_REG_R4000ALLEGREX_S_S122,
    RABBITIZER_REG_R4000ALLEGREX_S_S132,
    RABBITIZER_REG_R4000ALLEGREX_S_S202,
    RABBITIZER_REG_R4000ALLEGREX_S_S212,
    RABBITIZER_REG_R4000ALLEGREX_S_S222,
    RABBITIZER_REG_R4000ALLEGREX_S_S232,
    RABBITIZER_REG_R4000ALLEGREX_S_S302,
    RABBITIZER_REG_R4000ALLEGREX_S_S312,
    RABBITIZER_REG_R4000ALLEGREX_S_S322,
    RABBITIZER_REG_R4000ALLEGREX_S_S332,
    RABBITIZER_REG_R4000ALLEGREX_S_S402,
    RABBITIZER_REG_R4000ALLEGREX_S_S412,
    RABBITIZER_REG_R4000ALLEGREX_S_S422,
    RABBITIZER_REG_R4000ALLEGREX_S_S432,
    RABBITIZER_REG_R4000ALLEGREX_S_S502,
    RABBITIZER_REG_R4000ALLEGREX_S_S512,
    RABBITIZER_REG_R4000ALLEGREX_S_S522,
    RABBITIZER_REG_R4000ALLEGREX_S_S532,
    RABBITIZER_REG_R4000ALLEGREX_S_S602,
    RABBITIZER_REG_R4000ALLEGREX_S_S612,
    RABBITIZER_REG_R4000ALLEGREX_S_S622,
    RABBITIZER_REG_R4000ALLEGREX_S_S632,
    RABBITIZER_REG_R4000ALLEGREX_S_S702,
    RABBITIZER_REG_R4000ALLEGREX_S_S712,
    RABBITIZER_REG_R4000ALLEGREX_S_S722,
    RABBITIZER_REG_R4000ALLEGREX_S_S732,
    RABBITIZER_REG_R4000ALLEGREX_S_S003,
    RABBITIZER_REG_R4000ALLEGREX_S_S013,
    RABBITIZER_REG_R4000ALLEGREX_S_S023,
    RABBITIZER_REG_R4000ALLEGREX_S_S033,
    RABBITIZER_REG_R4000ALLEGREX_S_S103,
    RABBITIZER_REG_R4000ALLEGREX_S_S113,
    RABBITIZER_REG_R4000ALLEGREX_S_S123,
    RABBITIZER_REG_R4000ALLEGREX_S_S133,
    RABBITIZER_REG_R4000ALLEGREX_S_S203,
    RABBITIZER_REG_R4000ALLEGREX_S_S213,
    RABBITIZER_REG_R4000ALLEGREX_S_S223,
    RABBITIZER_REG_R4000ALLEGREX_S_S233,
    RABBITIZER_REG_R4000ALLEGREX_S_S303,
    RABBITIZER_REG_R4000ALLEGREX_S_S313,
    RABBITIZER_REG_R4000ALLEGREX_S_S323,
    RABBITIZER_REG_R4000ALLEGREX_S_S333,
    RABBITIZER_REG_R4000ALLEGREX_S_S403,
    RABBITIZER_REG_R4000ALLEGREX_S_S413,
    RABBITIZER_REG_R4000ALLEGREX_S_S423,
    RABBITIZER_REG_R4000ALLEGREX_S_S433,
    RABBITIZER_REG_R4000ALLEGREX_S_S503,
    RABBITIZER_REG_R4000ALLEGREX_S_S513,
    RABBITIZER_REG_R4000ALLEGREX_S_S523,
    RABBITIZER_REG_R4000ALLEGREX_S_S533,
    RABBITIZER_REG_R4000ALLEGREX_S_S603,
    RABBITIZER_REG_R4000ALLEGREX_S_S613,
    RABBITIZER_REG_R4000ALLEGREX_S_S623,
    RABBITIZER_REG_R4000ALLEGREX_S_S633,
    RABBITIZER_REG_R4000ALLEGREX_S_S703,
    RABBITIZER_REG_R4000ALLEGREX_S_S713,
    RABBITIZER_REG_R4000ALLEGREX_S_S723,
    RABBITIZER_REG_R4000ALLEGREX_S_S733,
} RabbitizerRegister_R4000AllegrexS;
typedef enum RabbitizerRegister_R4000AllegrexV2D {
    RABBITIZER_REG_R4000ALLEGREX_V2D_C000,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C010,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C020,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C030,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C100,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C110,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C120,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C130,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C200,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C210,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C220,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C230,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C300,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C310,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C320,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C330,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C400,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C410,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C420,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C430,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C500,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C510,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C520,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C530,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C600,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C610,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C620,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C630,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C700,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C710,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C720,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C730,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R000,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R001,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R002,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R003,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R100,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R101,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R102,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R103,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R200,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R201,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R202,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R203,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R300,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R301,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R302,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R303,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R400,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R401,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R402,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R403,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R500,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R501,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R502,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R503,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R600,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R601,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R602,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R603,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R700,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R701,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R702,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R703,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C002,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C012,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C022,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C032,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C102,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C112,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C122,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C132,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C202,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C212,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C222,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C232,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C302,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C312,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C322,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C332,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C402,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C412,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C422,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C432,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C502,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C512,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C522,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C532,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C602,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C612,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C622,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C632,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C702,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C712,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C722,
    RABBITIZER_REG_R4000ALLEGREX_V2D_C732,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R020,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R021,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R022,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R023,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R120,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R121,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R122,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R123,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R220,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R221,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R222,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R223,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R320,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R321,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R322,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R323,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R420,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R421,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R422,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R423,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R520,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R521,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R522,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R523,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R620,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R621,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R622,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R623,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R720,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R721,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R722,
    RABBITIZER_REG_R4000ALLEGREX_V2D_R723,
} RabbitizerRegister_R4000AllegrexV2D;
typedef enum RabbitizerRegister_R4000AllegrexV3D {
    RABBITIZER_REG_R4000ALLEGREX_V3D_C000,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C010,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C020,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C030,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C100,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C110,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C120,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C130,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C200,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C210,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C220,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C230,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C300,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C310,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C320,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C330,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C400,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C410,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C420,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C430,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C500,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C510,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C520,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C530,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C600,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C610,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C620,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C630,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C700,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C710,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C720,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C730,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R000,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R001,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R002,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R003,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R100,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R101,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R102,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R103,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R200,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R201,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R202,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R203,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R300,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R301,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R302,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R303,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R400,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R401,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R402,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R403,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R500,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R501,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R502,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R503,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R600,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R601,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R602,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R603,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R700,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R701,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R702,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R703,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C001,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C011,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C021,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C031,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C101,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C111,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C121,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C131,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C201,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C211,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C221,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C231,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C301,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C311,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C321,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C331,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C401,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C411,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C421,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C431,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C501,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C511,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C521,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C531,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C601,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C611,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C621,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C631,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C701,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C711,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C721,
    RABBITIZER_REG_R4000ALLEGREX_V3D_C731,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R010,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R011,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R012,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R013,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R110,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R111,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R112,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R113,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R210,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R211,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R212,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R213,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R310,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R311,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R312,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R313,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R410,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R411,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R412,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R413,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R510,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R511,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R512,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R513,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R610,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R611,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R612,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R613,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R710,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R711,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R712,
    RABBITIZER_REG_R4000ALLEGREX_V3D_R713,
} RabbitizerRegister_R4000AllegrexV3D;
typedef enum RabbitizerRegister_R4000AllegrexV4D {
    RABBITIZER_REG_R4000ALLEGREX_V4D_C000,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C010,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C020,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C030,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C100,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C110,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C120,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C130,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C200,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C210,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C220,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C230,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C300,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C310,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C320,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C330,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C400,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C410,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C420,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C430,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C500,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C510,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C520,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C530,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C600,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C610,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C620,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C630,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C700,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C710,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C720,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C730,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R000,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R001,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R002,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R003,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R100,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R101,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R102,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R103,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R200,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R201,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R202,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R203,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R300,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R301,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R302,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R303,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R400,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R401,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R402,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R403,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R500,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R501,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R502,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R503,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R600,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R601,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R602,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R603,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R700,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R701,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R702,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R703,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C002,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C012,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C022,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C032,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C102,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C112,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C122,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C132,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C202,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C212,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C222,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C232,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C302,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C312,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C322,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C332,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C402,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C412,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C422,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C432,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C502,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C512,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C522,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C532,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C602,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C612,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C622,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C632,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C702,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C712,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C722,
    RABBITIZER_REG_R4000ALLEGREX_V4D_C732,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R020,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R021,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R022,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R023,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R120,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R121,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R122,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R123,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R220,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R221,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R222,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R223,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R320,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R321,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R322,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R323,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R420,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R421,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R422,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R423,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R520,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R521,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R522,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R523,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R620,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R621,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R622,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R623,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R720,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R721,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R722,
    RABBITIZER_REG_R4000ALLEGREX_V4D_R723,
} RabbitizerRegister_R4000AllegrexV4D;
typedef enum RabbitizerRegister_R4000AllegrexM2x2 {
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M000,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M010,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M020,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M030,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M100,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M110,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M120,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M130,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M200,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M210,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M220,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M230,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M300,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M310,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M320,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M330,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M400,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M410,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M420,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M430,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M500,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M510,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M520,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M530,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M600,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M610,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M620,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M630,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M700,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M710,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M720,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M730,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E000,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E001,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E002,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E003,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E100,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E101,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E102,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E103,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E200,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E201,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E202,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E203,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E300,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E301,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E302,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E303,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E400,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E401,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E402,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E403,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E500,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E501,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E502,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E503,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E600,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E601,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E602,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E603,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E700,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E701,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E702,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E703,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M002,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M012,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M022,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M032,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M102,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M112,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M122,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M132,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M202,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M212,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M222,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M232,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M302,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M312,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M322,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M332,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M402,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M412,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M422,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M432,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M502,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M512,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M522,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M532,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M602,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M612,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M622,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M632,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M702,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M712,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M722,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_M732,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E020,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E021,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E022,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E023,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E120,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E121,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E122,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E123,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E220,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E221,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E222,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E223,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E320,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E321,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E322,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E323,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E420,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E421,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E422,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E423,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E520,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E521,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E522,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E523,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E620,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E621,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E622,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E623,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E720,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E721,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E722,
    RABBITIZER_REG_R4000ALLEGREX_M2X2_E723,
} RabbitizerRegister_R4000AllegrexM2x2;
typedef enum RabbitizerRegister_R4000AllegrexM3x3 {
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M000,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M010,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M020,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M030,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M100,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M110,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M120,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M130,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M200,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M210,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M220,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M230,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M300,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M310,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M320,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M330,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M400,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M410,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M420,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M430,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M500,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M510,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M520,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M530,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M600,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M610,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M620,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M630,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M700,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M710,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M720,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M730,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E000,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E001,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E002,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E003,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E100,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E101,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E102,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E103,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E200,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E201,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E202,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E203,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E300,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E301,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E302,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E303,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E400,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E401,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E402,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E403,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E500,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E501,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E502,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E503,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E600,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E601,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E602,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E603,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E700,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E701,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E702,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E703,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M001,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M011,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M021,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M031,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M101,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M111,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M121,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M131,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M201,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M211,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M221,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M231,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M301,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M311,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M321,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M331,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M401,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M411,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M421,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M431,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M501,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M511,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M521,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M531,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M601,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M611,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M621,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M631,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M701,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M711,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M721,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_M731,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E010,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E011,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E012,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E013,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E110,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E111,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E112,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E113,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E210,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E211,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E212,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E213,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E310,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E311,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E312,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E313,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E410,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E411,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E412,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E413,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E510,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E511,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E512,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E513,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E610,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E611,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E612,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E613,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E710,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E711,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E712,
    RABBITIZER_REG_R4000ALLEGREX_M3X3_E713,
} RabbitizerRegister_R4000AllegrexM3x3;
typedef enum RabbitizerRegister_R4000AllegrexM4x4 {
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M000,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M010,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M020,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M030,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M100,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M110,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M120,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M130,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M200,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M210,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M220,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M230,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M300,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M310,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M320,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M330,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M400,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M410,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M420,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M430,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M500,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M510,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M520,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M530,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M600,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M610,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M620,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M630,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M700,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M710,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M720,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M730,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E000,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E001,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E002,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E003,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E100,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E101,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E102,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E103,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E200,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E201,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E202,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E203,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E300,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E301,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E302,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E303,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E400,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E401,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E402,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E403,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E500,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E501,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E502,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E503,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E600,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E601,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E602,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E603,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E700,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E701,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E702,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E703,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M002,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M012,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M022,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M032,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M102,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M112,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M122,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M132,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M202,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M212,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M222,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M232,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M302,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M312,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M322,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M332,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M402,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M412,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M422,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M432,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M502,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M512,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M522,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M532,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M602,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M612,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M622,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M632,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M702,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M712,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M722,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_M732,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E020,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E021,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E022,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E023,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E120,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E121,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E122,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E123,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E220,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E221,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E222,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E223,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E320,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E321,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E322,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E323,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E420,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E421,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E422,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E423,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E520,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E521,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E522,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E523,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E620,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E621,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E622,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E623,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E720,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E721,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E722,
    RABBITIZER_REG_R4000ALLEGREX_M4X4_E723,
} RabbitizerRegister_R4000AllegrexM4x4;
typedef enum RabbitizerRegister_R4000AllegrexVfpuControl {
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_PFXS,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_PFXT,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_PFXD,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_CC,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_INF4,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RSV5,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RSV6,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_REV,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX0,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX1,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX2,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX3,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX4,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX5,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX6,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX7,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_144,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_145,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_146,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_147,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_148,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_149,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_150,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_151,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_152,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_153,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_154,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_155,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_156,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_157,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_158,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_159,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_160,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_161,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_162,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_163,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_164,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_165,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_166,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_167,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_168,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_169,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_170,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_171,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_172,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_173,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_174,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_175,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_176,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_177,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_178,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_179,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_180,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_181,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_182,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_183,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_184,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_185,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_186,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_187,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_188,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_189,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_190,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_191,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_192,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_193,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_194,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_195,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_196,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_197,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_198,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_199,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_200,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_201,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_202,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_203,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_204,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_205,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_206,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_207,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_208,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_209,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_210,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_211,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_212,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_213,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_214,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_215,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_216,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_217,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_218,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_219,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_220,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_221,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_222,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_223,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_224,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_225,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_226,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_227,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_228,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_229,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_230,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_231,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_232,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_233,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_234,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_235,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_236,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_237,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_238,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_239,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_240,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_241,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_242,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_243,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_244,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_245,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_246,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_247,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_248,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_249,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_250,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_251,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_252,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_253,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_254,
    RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_255,
} RabbitizerRegister_R4000AllegrexVfpuControl;
typedef enum RabbitizerRegister_R4000AllegrexVConstant {
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_0,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_HUGE,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_SQRT2,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_SQRT1_2,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_2_SQRTPI,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_2_PI,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_1_PI,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_PI_4,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_PI_2,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_PI,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_E,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LOG2E,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LOG10E,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LN2,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LN10,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_2PI,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_PI_6,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LOG10TWO,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LOG2TEN,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_SQRT3_2,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_20,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_21,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_22,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_23,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_24,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_25,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_26,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_27,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_28,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_29,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_30,
    RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_31,
} RabbitizerRegister_R4000AllegrexVConstant;
typedef enum RabbitizerRegister_R5900VF {
    RABBITIZER_REG_R5900_VF_vf0,
    RABBITIZER_REG_R5900_VF_vf1,
    RABBITIZER_REG_R5900_VF_vf2,
    RABBITIZER_REG_R5900_VF_vf3,
    RABBITIZER_REG_R5900_VF_vf4,
    RABBITIZER_REG_R5900_VF_vf5,
    RABBITIZER_REG_R5900_VF_vf6,
    RABBITIZER_REG_R5900_VF_vf7,
    RABBITIZER_REG_R5900_VF_vf8,
    RABBITIZER_REG_R5900_VF_vf9,
    RABBITIZER_REG_R5900_VF_vf10,
    RABBITIZER_REG_R5900_VF_vf11,
    RABBITIZER_REG_R5900_VF_vf12,
    RABBITIZER_REG_R5900_VF_vf13,
    RABBITIZER_REG_R5900_VF_vf14,
    RABBITIZER_REG_R5900_VF_vf15,
    RABBITIZER_REG_R5900_VF_vf16,
    RABBITIZER_REG_R5900_VF_vf17,
    RABBITIZER_REG_R5900_VF_vf18,
    RABBITIZER_REG_R5900_VF_vf19,
    RABBITIZER_REG_R5900_VF_vf20,
    RABBITIZER_REG_R5900_VF_vf21,
    RABBITIZER_REG_R5900_VF_vf22,
    RABBITIZER_REG_R5900_VF_vf23,
    RABBITIZER_REG_R5900_VF_vf24,
    RABBITIZER_REG_R5900_VF_vf25,
    RABBITIZER_REG_R5900_VF_vf26,
    RABBITIZER_REG_R5900_VF_vf27,
    RABBITIZER_REG_R5900_VF_vf28,
    RABBITIZER_REG_R5900_VF_vf29,
    RABBITIZER_REG_R5900_VF_vf30,
    RABBITIZER_REG_R5900_VF_vf31,
} RabbitizerRegister_R5900VF;
typedef enum RabbitizerRegister_R5900VI {
    RABBITIZER_REG_R5900_VI_vi0,
    RABBITIZER_REG_R5900_VI_vi1,
    RABBITIZER_REG_R5900_VI_vi2,
    RABBITIZER_REG_R5900_VI_vi3,
    RABBITIZER_REG_R5900_VI_vi4,
    RABBITIZER_REG_R5900_VI_vi5,
    RABBITIZER_REG_R5900_VI_vi6,
    RABBITIZER_REG_R5900_VI_vi7,
    RABBITIZER_REG_R5900_VI_vi8,
    RABBITIZER_REG_R5900_VI_vi9,
    RABBITIZER_REG_R5900_VI_vi10,
    RABBITIZER_REG_R5900_VI_vi11,
    RABBITIZER_REG_R5900_VI_vi12,
    RABBITIZER_REG_R5900_VI_vi13,
    RABBITIZER_REG_R5900_VI_vi14,
    RABBITIZER_REG_R5900_VI_vi15,
    RABBITIZER_REG_R5900_VI_vi16,
    RABBITIZER_REG_R5900_VI_vi17,
    RABBITIZER_REG_R5900_VI_vi18,
    RABBITIZER_REG_R5900_VI_vi19,
    RABBITIZER_REG_R5900_VI_vi20,
    RABBITIZER_REG_R5900_VI_vi21,
    RABBITIZER_REG_R5900_VI_vi22,
    RABBITIZER_REG_R5900_VI_vi23,
    RABBITIZER_REG_R5900_VI_vi24,
    RABBITIZER_REG_R5900_VI_vi25,
    RABBITIZER_REG_R5900_VI_vi26,
    RABBITIZER_REG_R5900_VI_vi27,
    RABBITIZER_REG_R5900_VI_vi28,
    RABBITIZER_REG_R5900_VI_vi29,
    RABBITIZER_REG_R5900_VI_vi30,
    RABBITIZER_REG_R5900_VI_vi31,
} RabbitizerRegister_R5900VI;

#endif
