/* SPDX-FileCopyrightText: © 2022-2024 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef InstrId_enum_h_automatic
#define InstrId_enum_h_automatic

typedef enum RabbitizerInstrId {
    RABBITIZER_INSTR_ID_cpu_INVALID,
    RABBITIZER_INSTR_ID_cpu_j,
    RABBITIZER_INSTR_ID_cpu_jal,
    RABBITIZER_INSTR_ID_cpu_beq,
    RABBITIZER_INSTR_ID_cpu_bne,
    RABBITIZER_INSTR_ID_cpu_beql,
    RABBITIZER_INSTR_ID_cpu_bnel,
    RABBITIZER_INSTR_ID_cpu_blez,
    RABBITIZER_INSTR_ID_cpu_blezl,
    RABBITIZER_INSTR_ID_cpu_bgtz,
    RABBITIZER_INSTR_ID_cpu_bgtzl,
    RABBITIZER_INSTR_ID_cpu_addi,
    RABBITIZER_INSTR_ID_cpu_addiu,
    RABBITIZER_INSTR_ID_cpu_slti,
    RABBITIZER_INSTR_ID_cpu_sltiu,
    RABBITIZER_INSTR_ID_cpu_andi,
    RABBITIZER_INSTR_ID_cpu_ori,
    RABBITIZER_INSTR_ID_cpu_xori,
    RABBITIZER_INSTR_ID_cpu_daddi,
    RABBITIZER_INSTR_ID_cpu_daddiu,
    RABBITIZER_INSTR_ID_cpu_lui,
    RABBITIZER_INSTR_ID_cpu_ldl,
    RABBITIZER_INSTR_ID_cpu_ldr,
    RABBITIZER_INSTR_ID_cpu_lb,
    RABBITIZER_INSTR_ID_cpu_lh,
    RABBITIZER_INSTR_ID_cpu_lwl,
    RABBITIZER_INSTR_ID_cpu_lw,
    RABBITIZER_INSTR_ID_cpu_lbu,
    RABBITIZER_INSTR_ID_cpu_lhu,
    RABBITIZER_INSTR_ID_cpu_lwr,
    RABBITIZER_INSTR_ID_cpu_lwu,
    RABBITIZER_INSTR_ID_cpu_sb,
    RABBITIZER_INSTR_ID_cpu_sh,
    RABBITIZER_INSTR_ID_cpu_swl,
    RABBITIZER_INSTR_ID_cpu_sw,
    RABBITIZER_INSTR_ID_cpu_sdl,
    RABBITIZER_INSTR_ID_cpu_sdr,
    RABBITIZER_INSTR_ID_cpu_swr,
    RABBITIZER_INSTR_ID_cpu_ll,
    RABBITIZER_INSTR_ID_cpu_pref,
    RABBITIZER_INSTR_ID_cpu_lld,
    RABBITIZER_INSTR_ID_cpu_ld,
    RABBITIZER_INSTR_ID_cpu_sc,
    RABBITIZER_INSTR_ID_cpu_scd,
    RABBITIZER_INSTR_ID_cpu_sd,
    RABBITIZER_INSTR_ID_cpu_cache,
    RABBITIZER_INSTR_ID_cpu_lwc1,
    RABBITIZER_INSTR_ID_cpu_ldc1,
    RABBITIZER_INSTR_ID_cpu_swc1,
    RABBITIZER_INSTR_ID_cpu_sdc1,
    RABBITIZER_INSTR_ID_cpu_lwc2,
    RABBITIZER_INSTR_ID_cpu_ldc2,
    RABBITIZER_INSTR_ID_cpu_swc2,
    RABBITIZER_INSTR_ID_cpu_sdc2,
    RABBITIZER_INSTR_ID_cpu_b,
    RABBITIZER_INSTR_ID_cpu_beqz,
    RABBITIZER_INSTR_ID_cpu_bnez,
    RABBITIZER_INSTR_ID_cpu_sll,
    RABBITIZER_INSTR_ID_cpu_srl,
    RABBITIZER_INSTR_ID_cpu_sra,
    RABBITIZER_INSTR_ID_cpu_dsll,
    RABBITIZER_INSTR_ID_cpu_dsrl,
    RABBITIZER_INSTR_ID_cpu_dsra,
    RABBITIZER_INSTR_ID_cpu_dsll32,
    RABBITIZER_INSTR_ID_cpu_dsrl32,
    RABBITIZER_INSTR_ID_cpu_dsra32,
    RABBITIZER_INSTR_ID_cpu_dsllv,
    RABBITIZER_INSTR_ID_cpu_dsrlv,
    RABBITIZER_INSTR_ID_cpu_dsrav,
    RABBITIZER_INSTR_ID_cpu_sllv,
    RABBITIZER_INSTR_ID_cpu_srlv,
    RABBITIZER_INSTR_ID_cpu_srav,
    RABBITIZER_INSTR_ID_cpu_mthi,
    RABBITIZER_INSTR_ID_cpu_mtlo,
    RABBITIZER_INSTR_ID_cpu_jr,
    RABBITIZER_INSTR_ID_cpu_jalr,
    RABBITIZER_INSTR_ID_cpu_mfhi,
    RABBITIZER_INSTR_ID_cpu_mflo,
    RABBITIZER_INSTR_ID_cpu_movz,
    RABBITIZER_INSTR_ID_cpu_movn,
    RABBITIZER_INSTR_ID_cpu_div,
    RABBITIZER_INSTR_ID_cpu_divu,
    RABBITIZER_INSTR_ID_cpu_sn64_div,
    RABBITIZER_INSTR_ID_cpu_sn64_divu,
    RABBITIZER_INSTR_ID_cpu_ddiv,
    RABBITIZER_INSTR_ID_cpu_ddivu,
    RABBITIZER_INSTR_ID_cpu_add,
    RABBITIZER_INSTR_ID_cpu_addu,
    RABBITIZER_INSTR_ID_cpu_sub,
    RABBITIZER_INSTR_ID_cpu_subu,
    RABBITIZER_INSTR_ID_cpu_and,
    RABBITIZER_INSTR_ID_cpu_or,
    RABBITIZER_INSTR_ID_cpu_xor,
    RABBITIZER_INSTR_ID_cpu_nor,
    RABBITIZER_INSTR_ID_cpu_slt,
    RABBITIZER_INSTR_ID_cpu_sltu,
    RABBITIZER_INSTR_ID_cpu_dadd,
    RABBITIZER_INSTR_ID_cpu_daddu,
    RABBITIZER_INSTR_ID_cpu_dsub,
    RABBITIZER_INSTR_ID_cpu_dsubu,
    RABBITIZER_INSTR_ID_cpu_syscall,
    RABBITIZER_INSTR_ID_cpu_break,
    RABBITIZER_INSTR_ID_cpu_sync,
    RABBITIZER_INSTR_ID_cpu_mult,
    RABBITIZER_INSTR_ID_cpu_multu,
    RABBITIZER_INSTR_ID_cpu_dmult,
    RABBITIZER_INSTR_ID_cpu_dmultu,
    RABBITIZER_INSTR_ID_cpu_tge,
    RABBITIZER_INSTR_ID_cpu_tgeu,
    RABBITIZER_INSTR_ID_cpu_tlt,
    RABBITIZER_INSTR_ID_cpu_tltu,
    RABBITIZER_INSTR_ID_cpu_teq,
    RABBITIZER_INSTR_ID_cpu_tne,
    RABBITIZER_INSTR_ID_cpu_nop,
    RABBITIZER_INSTR_ID_cpu_move,
    RABBITIZER_INSTR_ID_cpu_not,
    RABBITIZER_INSTR_ID_cpu_neg,
    RABBITIZER_INSTR_ID_cpu_negu,
    RABBITIZER_INSTR_ID_cpu_bltz,
    RABBITIZER_INSTR_ID_cpu_bgez,
    RABBITIZER_INSTR_ID_cpu_bltzl,
    RABBITIZER_INSTR_ID_cpu_bgezl,
    RABBITIZER_INSTR_ID_cpu_tgei,
    RABBITIZER_INSTR_ID_cpu_tgeiu,
    RABBITIZER_INSTR_ID_cpu_tlti,
    RABBITIZER_INSTR_ID_cpu_tltiu,
    RABBITIZER_INSTR_ID_cpu_teqi,
    RABBITIZER_INSTR_ID_cpu_tnei,
    RABBITIZER_INSTR_ID_cpu_bltzal,
    RABBITIZER_INSTR_ID_cpu_bgezal,
    RABBITIZER_INSTR_ID_cpu_bltzall,
    RABBITIZER_INSTR_ID_cpu_bgezall,
    RABBITIZER_INSTR_ID_cpu_bal,
    RABBITIZER_INSTR_ID_cpu_mfc0,
    RABBITIZER_INSTR_ID_cpu_dmfc0,
    RABBITIZER_INSTR_ID_cpu_cfc0,
    RABBITIZER_INSTR_ID_cpu_mtc0,
    RABBITIZER_INSTR_ID_cpu_dmtc0,
    RABBITIZER_INSTR_ID_cpu_ctc0,
    RABBITIZER_INSTR_ID_cpu_bc0f,
    RABBITIZER_INSTR_ID_cpu_bc0t,
    RABBITIZER_INSTR_ID_cpu_bc0fl,
    RABBITIZER_INSTR_ID_cpu_bc0tl,
    RABBITIZER_INSTR_ID_cpu_tlbr,
    RABBITIZER_INSTR_ID_cpu_tlbwi,
    RABBITIZER_INSTR_ID_cpu_tlbwr,
    RABBITIZER_INSTR_ID_cpu_tlbp,
    RABBITIZER_INSTR_ID_cpu_rfe,
    RABBITIZER_INSTR_ID_cpu_eret,
    RABBITIZER_INSTR_ID_cpu_mfc1,
    RABBITIZER_INSTR_ID_cpu_dmfc1,
    RABBITIZER_INSTR_ID_cpu_mtc1,
    RABBITIZER_INSTR_ID_cpu_dmtc1,
    RABBITIZER_INSTR_ID_cpu_cfc1,
    RABBITIZER_INSTR_ID_cpu_ctc1,
    RABBITIZER_INSTR_ID_cpu_bc1f,
    RABBITIZER_INSTR_ID_cpu_bc1t,
    RABBITIZER_INSTR_ID_cpu_bc1fl,
    RABBITIZER_INSTR_ID_cpu_bc1tl,
    RABBITIZER_INSTR_ID_cpu_add_s,
    RABBITIZER_INSTR_ID_cpu_sub_s,
    RABBITIZER_INSTR_ID_cpu_mul_s,
    RABBITIZER_INSTR_ID_cpu_div_s,
    RABBITIZER_INSTR_ID_cpu_sqrt_s,
    RABBITIZER_INSTR_ID_cpu_abs_s,
    RABBITIZER_INSTR_ID_cpu_mov_s,
    RABBITIZER_INSTR_ID_cpu_neg_s,
    RABBITIZER_INSTR_ID_cpu_round_l_s,
    RABBITIZER_INSTR_ID_cpu_trunc_l_s,
    RABBITIZER_INSTR_ID_cpu_ceil_l_s,
    RABBITIZER_INSTR_ID_cpu_floor_l_s,
    RABBITIZER_INSTR_ID_cpu_round_w_s,
    RABBITIZER_INSTR_ID_cpu_trunc_w_s,
    RABBITIZER_INSTR_ID_cpu_ceil_w_s,
    RABBITIZER_INSTR_ID_cpu_floor_w_s,
    RABBITIZER_INSTR_ID_cpu_cvt_d_s,
    RABBITIZER_INSTR_ID_cpu_cvt_w_s,
    RABBITIZER_INSTR_ID_cpu_cvt_l_s,
    RABBITIZER_INSTR_ID_cpu_c_f_s,
    RABBITIZER_INSTR_ID_cpu_c_un_s,
    RABBITIZER_INSTR_ID_cpu_c_eq_s,
    RABBITIZER_INSTR_ID_cpu_c_ueq_s,
    RABBITIZER_INSTR_ID_cpu_c_olt_s,
    RABBITIZER_INSTR_ID_cpu_c_ult_s,
    RABBITIZER_INSTR_ID_cpu_c_ole_s,
    RABBITIZER_INSTR_ID_cpu_c_ule_s,
    RABBITIZER_INSTR_ID_cpu_c_sf_s,
    RABBITIZER_INSTR_ID_cpu_c_ngle_s,
    RABBITIZER_INSTR_ID_cpu_c_seq_s,
    RABBITIZER_INSTR_ID_cpu_c_ngl_s,
    RABBITIZER_INSTR_ID_cpu_c_lt_s,
    RABBITIZER_INSTR_ID_cpu_c_nge_s,
    RABBITIZER_INSTR_ID_cpu_c_le_s,
    RABBITIZER_INSTR_ID_cpu_c_ngt_s,
    RABBITIZER_INSTR_ID_cpu_add_d,
    RABBITIZER_INSTR_ID_cpu_sub_d,
    RABBITIZER_INSTR_ID_cpu_mul_d,
    RABBITIZER_INSTR_ID_cpu_div_d,
    RABBITIZER_INSTR_ID_cpu_sqrt_d,
    RABBITIZER_INSTR_ID_cpu_abs_d,
    RABBITIZER_INSTR_ID_cpu_mov_d,
    RABBITIZER_INSTR_ID_cpu_neg_d,
    RABBITIZER_INSTR_ID_cpu_round_l_d,
    RABBITIZER_INSTR_ID_cpu_trunc_l_d,
    RABBITIZER_INSTR_ID_cpu_ceil_l_d,
    RABBITIZER_INSTR_ID_cpu_floor_l_d,
    RABBITIZER_INSTR_ID_cpu_round_w_d,
    RABBITIZER_INSTR_ID_cpu_trunc_w_d,
    RABBITIZER_INSTR_ID_cpu_ceil_w_d,
    RABBITIZER_INSTR_ID_cpu_floor_w_d,
    RABBITIZER_INSTR_ID_cpu_cvt_s_d,
    RABBITIZER_INSTR_ID_cpu_cvt_w_d,
    RABBITIZER_INSTR_ID_cpu_cvt_l_d,
    RABBITIZER_INSTR_ID_cpu_c_f_d,
    RABBITIZER_INSTR_ID_cpu_c_un_d,
    RABBITIZER_INSTR_ID_cpu_c_eq_d,
    RABBITIZER_INSTR_ID_cpu_c_ueq_d,
    RABBITIZER_INSTR_ID_cpu_c_olt_d,
    RABBITIZER_INSTR_ID_cpu_c_ult_d,
    RABBITIZER_INSTR_ID_cpu_c_ole_d,
    RABBITIZER_INSTR_ID_cpu_c_ule_d,
    RABBITIZER_INSTR_ID_cpu_c_df_d,
    RABBITIZER_INSTR_ID_cpu_c_ngle_d,
    RABBITIZER_INSTR_ID_cpu_c_seq_d,
    RABBITIZER_INSTR_ID_cpu_c_ngl_d,
    RABBITIZER_INSTR_ID_cpu_c_lt_d,
    RABBITIZER_INSTR_ID_cpu_c_nge_d,
    RABBITIZER_INSTR_ID_cpu_c_le_d,
    RABBITIZER_INSTR_ID_cpu_c_ngt_d,
    RABBITIZER_INSTR_ID_cpu_cvt_s_w,
    RABBITIZER_INSTR_ID_cpu_cvt_d_w,
    RABBITIZER_INSTR_ID_cpu_cvt_s_l,
    RABBITIZER_INSTR_ID_cpu_cvt_d_l,
    RABBITIZER_INSTR_ID_cpu_mfc2,
    RABBITIZER_INSTR_ID_cpu_mtc2,
    RABBITIZER_INSTR_ID_cpu_cfc2,
    RABBITIZER_INSTR_ID_cpu_ctc2,
    RABBITIZER_INSTR_ID_cpu_USERDEF_00,
    RABBITIZER_INSTR_ID_cpu_USERDEF_01,
    RABBITIZER_INSTR_ID_cpu_USERDEF_02,
    RABBITIZER_INSTR_ID_cpu_USERDEF_03,
    RABBITIZER_INSTR_ID_cpu_USERDEF_04,
    RABBITIZER_INSTR_ID_cpu_USERDEF_05,
    RABBITIZER_INSTR_ID_cpu_USERDEF_06,
    RABBITIZER_INSTR_ID_cpu_USERDEF_07,
    RABBITIZER_INSTR_ID_cpu_USERDEF_08,
    RABBITIZER_INSTR_ID_cpu_USERDEF_09,
    RABBITIZER_INSTR_ID_cpu_USERDEF_10,
    RABBITIZER_INSTR_ID_cpu_USERDEF_11,
    RABBITIZER_INSTR_ID_cpu_USERDEF_12,
    RABBITIZER_INSTR_ID_cpu_USERDEF_13,
    RABBITIZER_INSTR_ID_cpu_USERDEF_14,
    RABBITIZER_INSTR_ID_cpu_USERDEF_15,
    RABBITIZER_INSTR_ID_cpu_USERDEF_16,
    RABBITIZER_INSTR_ID_cpu_USERDEF_17,
    RABBITIZER_INSTR_ID_cpu_USERDEF_18,
    RABBITIZER_INSTR_ID_cpu_USERDEF_19,
    RABBITIZER_INSTR_ID_cpu_MAX,
    RABBITIZER_INSTR_ID_rsp_INVALID,
    RABBITIZER_INSTR_ID_rsp_mfc2,
    RABBITIZER_INSTR_ID_rsp_mtc2,
    RABBITIZER_INSTR_ID_rsp_cfc2,
    RABBITIZER_INSTR_ID_rsp_ctc2,
    RABBITIZER_INSTR_ID_rsp_vmulf,
    RABBITIZER_INSTR_ID_rsp_vmulu,
    RABBITIZER_INSTR_ID_rsp_vrndp,
    RABBITIZER_INSTR_ID_rsp_vmulq,
    RABBITIZER_INSTR_ID_rsp_vmudl,
    RABBITIZER_INSTR_ID_rsp_vmudm,
    RABBITIZER_INSTR_ID_rsp_vmudn,
    RABBITIZER_INSTR_ID_rsp_vmudh,
    RABBITIZER_INSTR_ID_rsp_vmacf,
    RABBITIZER_INSTR_ID_rsp_vmacu,
    RABBITIZER_INSTR_ID_rsp_vrndn,
    RABBITIZER_INSTR_ID_rsp_vmacq,
    RABBITIZER_INSTR_ID_rsp_vmadl,
    RABBITIZER_INSTR_ID_rsp_vmadm,
    RABBITIZER_INSTR_ID_rsp_vmadn,
    RABBITIZER_INSTR_ID_rsp_vmadh,
    RABBITIZER_INSTR_ID_rsp_vadd,
    RABBITIZER_INSTR_ID_rsp_vsub,
    RABBITIZER_INSTR_ID_rsp_vabs,
    RABBITIZER_INSTR_ID_rsp_vaddc,
    RABBITIZER_INSTR_ID_rsp_vsubc,
    RABBITIZER_INSTR_ID_rsp_vsar,
    RABBITIZER_INSTR_ID_rsp_vand,
    RABBITIZER_INSTR_ID_rsp_vnand,
    RABBITIZER_INSTR_ID_rsp_vor,
    RABBITIZER_INSTR_ID_rsp_vnor,
    RABBITIZER_INSTR_ID_rsp_vxor,
    RABBITIZER_INSTR_ID_rsp_vnxor,
    RABBITIZER_INSTR_ID_rsp_vlt,
    RABBITIZER_INSTR_ID_rsp_veq,
    RABBITIZER_INSTR_ID_rsp_vne,
    RABBITIZER_INSTR_ID_rsp_vge,
    RABBITIZER_INSTR_ID_rsp_vcl,
    RABBITIZER_INSTR_ID_rsp_vch,
    RABBITIZER_INSTR_ID_rsp_vcr,
    RABBITIZER_INSTR_ID_rsp_vmrg,
    RABBITIZER_INSTR_ID_rsp_vrcp,
    RABBITIZER_INSTR_ID_rsp_vrcpl,
    RABBITIZER_INSTR_ID_rsp_vrcph,
    RABBITIZER_INSTR_ID_rsp_vmov,
    RABBITIZER_INSTR_ID_rsp_vrsq,
    RABBITIZER_INSTR_ID_rsp_vrsql,
    RABBITIZER_INSTR_ID_rsp_vrsqh,
    RABBITIZER_INSTR_ID_rsp_vnop,
    RABBITIZER_INSTR_ID_rsp_lbv,
    RABBITIZER_INSTR_ID_rsp_lsv,
    RABBITIZER_INSTR_ID_rsp_llv,
    RABBITIZER_INSTR_ID_rsp_ldv,
    RABBITIZER_INSTR_ID_rsp_lqv,
    RABBITIZER_INSTR_ID_rsp_lrv,
    RABBITIZER_INSTR_ID_rsp_lpv,
    RABBITIZER_INSTR_ID_rsp_luv,
    RABBITIZER_INSTR_ID_rsp_lhv,
    RABBITIZER_INSTR_ID_rsp_lfv,
    RABBITIZER_INSTR_ID_rsp_ltv,
    RABBITIZER_INSTR_ID_rsp_sbv,
    RABBITIZER_INSTR_ID_rsp_ssv,
    RABBITIZER_INSTR_ID_rsp_slv,
    RABBITIZER_INSTR_ID_rsp_sdv,
    RABBITIZER_INSTR_ID_rsp_sqv,
    RABBITIZER_INSTR_ID_rsp_srv,
    RABBITIZER_INSTR_ID_rsp_spv,
    RABBITIZER_INSTR_ID_rsp_suv,
    RABBITIZER_INSTR_ID_rsp_shv,
    RABBITIZER_INSTR_ID_rsp_sfv,
    RABBITIZER_INSTR_ID_rsp_stv,
    RABBITIZER_INSTR_ID_rsp_swv,
    RABBITIZER_INSTR_ID_rsp_j,
    RABBITIZER_INSTR_ID_rsp_jal,
    RABBITIZER_INSTR_ID_rsp_beq,
    RABBITIZER_INSTR_ID_rsp_bne,
    RABBITIZER_INSTR_ID_rsp_blez,
    RABBITIZER_INSTR_ID_rsp_bgtz,
    RABBITIZER_INSTR_ID_rsp_addi,
    RABBITIZER_INSTR_ID_rsp_addiu,
    RABBITIZER_INSTR_ID_rsp_slti,
    RABBITIZER_INSTR_ID_rsp_sltiu,
    RABBITIZER_INSTR_ID_rsp_andi,
    RABBITIZER_INSTR_ID_rsp_ori,
    RABBITIZER_INSTR_ID_rsp_xori,
    RABBITIZER_INSTR_ID_rsp_lui,
    RABBITIZER_INSTR_ID_rsp_lb,
    RABBITIZER_INSTR_ID_rsp_lh,
    RABBITIZER_INSTR_ID_rsp_lw,
    RABBITIZER_INSTR_ID_rsp_lbu,
    RABBITIZER_INSTR_ID_rsp_lhu,
    RABBITIZER_INSTR_ID_rsp_sb,
    RABBITIZER_INSTR_ID_rsp_sh,
    RABBITIZER_INSTR_ID_rsp_sw,
    RABBITIZER_INSTR_ID_rsp_pref,
    RABBITIZER_INSTR_ID_rsp_b,
    RABBITIZER_INSTR_ID_rsp_beqz,
    RABBITIZER_INSTR_ID_rsp_bnez,
    RABBITIZER_INSTR_ID_rsp_sll,
    RABBITIZER_INSTR_ID_rsp_srl,
    RABBITIZER_INSTR_ID_rsp_sra,
    RABBITIZER_INSTR_ID_rsp_sllv,
    RABBITIZER_INSTR_ID_rsp_srlv,
    RABBITIZER_INSTR_ID_rsp_srav,
    RABBITIZER_INSTR_ID_rsp_jr,
    RABBITIZER_INSTR_ID_rsp_jalr,
    RABBITIZER_INSTR_ID_rsp_movz,
    RABBITIZER_INSTR_ID_rsp_movn,
    RABBITIZER_INSTR_ID_rsp_add,
    RABBITIZER_INSTR_ID_rsp_addu,
    RABBITIZER_INSTR_ID_rsp_sub,
    RABBITIZER_INSTR_ID_rsp_subu,
    RABBITIZER_INSTR_ID_rsp_and,
    RABBITIZER_INSTR_ID_rsp_or,
    RABBITIZER_INSTR_ID_rsp_xor,
    RABBITIZER_INSTR_ID_rsp_nor,
    RABBITIZER_INSTR_ID_rsp_slt,
    RABBITIZER_INSTR_ID_rsp_sltu,
    RABBITIZER_INSTR_ID_rsp_break,
    RABBITIZER_INSTR_ID_rsp_nop,
    RABBITIZER_INSTR_ID_rsp_move,
    RABBITIZER_INSTR_ID_rsp_not,
    RABBITIZER_INSTR_ID_rsp_neg,
    RABBITIZER_INSTR_ID_rsp_negu,
    RABBITIZER_INSTR_ID_rsp_bltz,
    RABBITIZER_INSTR_ID_rsp_bgez,
    RABBITIZER_INSTR_ID_rsp_bltzal,
    RABBITIZER_INSTR_ID_rsp_bgezal,
    RABBITIZER_INSTR_ID_rsp_bal,
    RABBITIZER_INSTR_ID_rsp_mfc0,
    RABBITIZER_INSTR_ID_rsp_mtc0,
    RABBITIZER_INSTR_ID_rsp_USERDEF_00,
    RABBITIZER_INSTR_ID_rsp_USERDEF_01,
    RABBITIZER_INSTR_ID_rsp_USERDEF_02,
    RABBITIZER_INSTR_ID_rsp_USERDEF_03,
    RABBITIZER_INSTR_ID_rsp_USERDEF_04,
    RABBITIZER_INSTR_ID_rsp_USERDEF_05,
    RABBITIZER_INSTR_ID_rsp_USERDEF_06,
    RABBITIZER_INSTR_ID_rsp_USERDEF_07,
    RABBITIZER_INSTR_ID_rsp_USERDEF_08,
    RABBITIZER_INSTR_ID_rsp_USERDEF_09,
    RABBITIZER_INSTR_ID_rsp_USERDEF_10,
    RABBITIZER_INSTR_ID_rsp_USERDEF_11,
    RABBITIZER_INSTR_ID_rsp_USERDEF_12,
    RABBITIZER_INSTR_ID_rsp_USERDEF_13,
    RABBITIZER_INSTR_ID_rsp_USERDEF_14,
    RABBITIZER_INSTR_ID_rsp_USERDEF_15,
    RABBITIZER_INSTR_ID_rsp_USERDEF_16,
    RABBITIZER_INSTR_ID_rsp_USERDEF_17,
    RABBITIZER_INSTR_ID_rsp_USERDEF_18,
    RABBITIZER_INSTR_ID_rsp_USERDEF_19,
    RABBITIZER_INSTR_ID_rsp_MAX,
    RABBITIZER_INSTR_ID_r3000gte_INVALID,
    RABBITIZER_INSTR_ID_r3000gte_rtps,
    RABBITIZER_INSTR_ID_r3000gte_rtpt,
    RABBITIZER_INSTR_ID_r3000gte_dpcl,
    RABBITIZER_INSTR_ID_r3000gte_dpcs,
    RABBITIZER_INSTR_ID_r3000gte_dpct,
    RABBITIZER_INSTR_ID_r3000gte_intpl,
    RABBITIZER_INSTR_ID_r3000gte_ncs,
    RABBITIZER_INSTR_ID_r3000gte_nct,
    RABBITIZER_INSTR_ID_r3000gte_ncds,
    RABBITIZER_INSTR_ID_r3000gte_ncdt,
    RABBITIZER_INSTR_ID_r3000gte_nccs,
    RABBITIZER_INSTR_ID_r3000gte_ncct,
    RABBITIZER_INSTR_ID_r3000gte_cdp,
    RABBITIZER_INSTR_ID_r3000gte_cc,
    RABBITIZER_INSTR_ID_r3000gte_nclip,
    RABBITIZER_INSTR_ID_r3000gte_avsz3,
    RABBITIZER_INSTR_ID_r3000gte_avsz4,
    RABBITIZER_INSTR_ID_r3000gte_mvmva,
    RABBITIZER_INSTR_ID_r3000gte_sqr,
    RABBITIZER_INSTR_ID_r3000gte_op,
    RABBITIZER_INSTR_ID_r3000gte_gpf,
    RABBITIZER_INSTR_ID_r3000gte_gpl,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_00,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_01,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_02,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_03,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_04,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_05,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_06,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_07,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_08,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_09,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_10,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_11,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_12,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_13,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_14,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_15,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_16,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_17,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_18,
    RABBITIZER_INSTR_ID_r3000gte_USERDEF_19,
    RABBITIZER_INSTR_ID_r3000gte_MAX,
    RABBITIZER_INSTR_ID_r4000allegrex_INVALID,
    RABBITIZER_INSTR_ID_r4000allegrex_lv_s,
    RABBITIZER_INSTR_ID_r4000allegrex_sv_s,
    RABBITIZER_INSTR_ID_r4000allegrex_lv_q,
    RABBITIZER_INSTR_ID_r4000allegrex_sv_q,
    RABBITIZER_INSTR_ID_r4000allegrex_clz,
    RABBITIZER_INSTR_ID_r4000allegrex_clo,
    RABBITIZER_INSTR_ID_r4000allegrex_madd,
    RABBITIZER_INSTR_ID_r4000allegrex_maddu,
    RABBITIZER_INSTR_ID_r4000allegrex_msub,
    RABBITIZER_INSTR_ID_r4000allegrex_msubu,
    RABBITIZER_INSTR_ID_r4000allegrex_max,
    RABBITIZER_INSTR_ID_r4000allegrex_min,
    RABBITIZER_INSTR_ID_r4000allegrex_srl,
    RABBITIZER_INSTR_ID_r4000allegrex_rotr,
    RABBITIZER_INSTR_ID_r4000allegrex_srlv,
    RABBITIZER_INSTR_ID_r4000allegrex_rotrv,
    RABBITIZER_INSTR_ID_r4000allegrex_sleep,
    RABBITIZER_INSTR_ID_r4000allegrex_mfie,
    RABBITIZER_INSTR_ID_r4000allegrex_mtie,
    RABBITIZER_INSTR_ID_r4000allegrex_ext,
    RABBITIZER_INSTR_ID_r4000allegrex_ins,
    RABBITIZER_INSTR_ID_r4000allegrex_wsbh,
    RABBITIZER_INSTR_ID_r4000allegrex_wsbw,
    RABBITIZER_INSTR_ID_r4000allegrex_seb,
    RABBITIZER_INSTR_ID_r4000allegrex_seh,
    RABBITIZER_INSTR_ID_r4000allegrex_bitrev,
    RABBITIZER_INSTR_ID_r4000allegrex_bvf,
    RABBITIZER_INSTR_ID_r4000allegrex_bvt,
    RABBITIZER_INSTR_ID_r4000allegrex_bvfl,
    RABBITIZER_INSTR_ID_r4000allegrex_bvtl,
    RABBITIZER_INSTR_ID_r4000allegrex_mfv,
    RABBITIZER_INSTR_ID_r4000allegrex_mfvc,
    RABBITIZER_INSTR_ID_r4000allegrex_vsync2,
    RABBITIZER_INSTR_ID_r4000allegrex_mtv,
    RABBITIZER_INSTR_ID_r4000allegrex_mtvc,
    RABBITIZER_INSTR_ID_r4000allegrex_vadd_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vadd_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vadd_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vadd_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsub_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vsub_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vsub_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vsub_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsbn_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vdiv_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vdiv_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vdiv_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vdiv_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vmul_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vmul_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmul_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmul_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vdot_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vdot_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vdot_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vscl_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vscl_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vscl_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vhdp_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vhdp_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vhdp_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vcrs_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vdet_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmp_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmp_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmp_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmp_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vmin_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vmin_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmin_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmin_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vmax_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vmax_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmax_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmax_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vscmp_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vscmp_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vscmp_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vscmp_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsge_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vsge_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vsge_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vsge_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vslt_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vslt_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vslt_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vslt_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vwbn_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vmov_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vmov_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmov_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmov_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vabs_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vabs_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vabs_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vabs_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vneg_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vneg_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vneg_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vneg_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vidt_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vidt_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsat0_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vsat0_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vsat0_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vsat0_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsat1_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vsat1_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vsat1_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vsat1_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vzero_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vzero_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vzero_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vzero_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vone_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vone_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vone_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vone_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vrcp_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vrcp_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vrcp_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vrcp_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vrsq_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vrsq_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vrsq_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vrsq_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsin_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vsin_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vsin_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vsin_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vcos_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vcos_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vcos_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vcos_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vexp2_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vexp2_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vexp2_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vexp2_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vlog2_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vlog2_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vlog2_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vlog2_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsqrt_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vsqrt_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vsqrt_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vsqrt_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vasin_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vasin_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vasin_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vasin_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vnrcp_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vnrcp_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vnrcp_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vnrcp_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vnsin_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vnsin_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vnsin_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vnsin_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vrexp2_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vrexp2_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vrexp2_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vrexp2_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vrnds_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndi_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndi_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndi_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndi_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndf1_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndf1_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndf1_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndf1_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndf2_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndf2_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndf2_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vrndf2_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2h_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2h_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vh2f_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vh2f_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vsbz_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vlgb_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vuc2ifs_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vc2i_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vus2i_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vus2i_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vs2i_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vs2i_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2uc_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2c_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2us_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2us_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2s_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2s_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsrt1_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsrt2_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vbfy1_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vbfy1_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vbfy2_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vocp_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vocp_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vocp_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vocp_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsocp_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vsocp_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vfad_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vfad_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vfad_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vavg_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vavg_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vavg_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsrt3_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsrt4_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vsgn_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vsgn_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vsgn_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vsgn_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vmfvc,
    RABBITIZER_INSTR_ID_r4000allegrex_vmtvc,
    RABBITIZER_INSTR_ID_r4000allegrex_vt4444_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vt5551_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vt5650_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vcst_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vcst_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vcst_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vcst_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2in_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2in_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2in_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2in_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2iz_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2iz_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2iz_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2iz_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2iu_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2iu_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2iu_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2iu_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2id_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2id_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2id_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vf2id_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2f_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2f_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2f_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vi2f_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmovt_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmovt_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmovt_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmovt_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmovf_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmovf_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmovf_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vcmovf_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vpfxs,
    RABBITIZER_INSTR_ID_r4000allegrex_vpfxt,
    RABBITIZER_INSTR_ID_r4000allegrex_vpfxd,
    RABBITIZER_INSTR_ID_r4000allegrex_viim_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vfim_s,
    RABBITIZER_INSTR_ID_r4000allegrex_vmmul_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmmul_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmmul_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vhtfm2_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vtfm2_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vhtfm3_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vtfm3_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vhtfm4_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vtfm4_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vmscl_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmscl_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmscl_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vcrsp_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vqmul_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vrot_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vrot_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vrot_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vmmov_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmmov_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmmov_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vmidt_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmidt_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmidt_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vmzero_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmzero_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmzero_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vmone_p,
    RABBITIZER_INSTR_ID_r4000allegrex_vmone_t,
    RABBITIZER_INSTR_ID_r4000allegrex_vmone_q,
    RABBITIZER_INSTR_ID_r4000allegrex_vnop,
    RABBITIZER_INSTR_ID_r4000allegrex_vsync,
    RABBITIZER_INSTR_ID_r4000allegrex_vflush,
    RABBITIZER_INSTR_ID_r4000allegrex_svl_q,
    RABBITIZER_INSTR_ID_r4000allegrex_svr_q,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_00,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_01,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_02,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_03,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_04,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_05,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_06,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_07,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_08,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_09,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_10,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_11,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_12,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_13,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_14,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_15,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_16,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_17,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_18,
    RABBITIZER_INSTR_ID_r4000allegrex_USERDEF_19,
    RABBITIZER_INSTR_ID_r4000allegrex_MAX,
    RABBITIZER_INSTR_ID_r5900_INVALID,
    RABBITIZER_INSTR_ID_r5900_lq,
    RABBITIZER_INSTR_ID_r5900_sq,
    RABBITIZER_INSTR_ID_r5900_lqc2,
    RABBITIZER_INSTR_ID_r5900_sqc2,
    RABBITIZER_INSTR_ID_r5900_sync_p,
    RABBITIZER_INSTR_ID_r5900_mult,
    RABBITIZER_INSTR_ID_r5900_mfsa,
    RABBITIZER_INSTR_ID_r5900_mtsa,
    RABBITIZER_INSTR_ID_r5900_mtsab,
    RABBITIZER_INSTR_ID_r5900_mtsah,
    RABBITIZER_INSTR_ID_r5900_madd,
    RABBITIZER_INSTR_ID_r5900_maddu,
    RABBITIZER_INSTR_ID_r5900_plzcw,
    RABBITIZER_INSTR_ID_r5900_mfhi1,
    RABBITIZER_INSTR_ID_r5900_mthi1,
    RABBITIZER_INSTR_ID_r5900_mflo1,
    RABBITIZER_INSTR_ID_r5900_mtlo1,
    RABBITIZER_INSTR_ID_r5900_mult1,
    RABBITIZER_INSTR_ID_r5900_multu1,
    RABBITIZER_INSTR_ID_r5900_div1,
    RABBITIZER_INSTR_ID_r5900_divu1,
    RABBITIZER_INSTR_ID_r5900_madd1,
    RABBITIZER_INSTR_ID_r5900_maddu1,
    RABBITIZER_INSTR_ID_r5900_psllh,
    RABBITIZER_INSTR_ID_r5900_psrlh,
    RABBITIZER_INSTR_ID_r5900_psrah,
    RABBITIZER_INSTR_ID_r5900_psllw,
    RABBITIZER_INSTR_ID_r5900_psrlw,
    RABBITIZER_INSTR_ID_r5900_psraw,
    RABBITIZER_INSTR_ID_r5900_paddw,
    RABBITIZER_INSTR_ID_r5900_psubw,
    RABBITIZER_INSTR_ID_r5900_pcgtw,
    RABBITIZER_INSTR_ID_r5900_pmaxw,
    RABBITIZER_INSTR_ID_r5900_paddh,
    RABBITIZER_INSTR_ID_r5900_psubh,
    RABBITIZER_INSTR_ID_r5900_pcgth,
    RABBITIZER_INSTR_ID_r5900_pmaxh,
    RABBITIZER_INSTR_ID_r5900_paddb,
    RABBITIZER_INSTR_ID_r5900_psubb,
    RABBITIZER_INSTR_ID_r5900_pcgtb,
    RABBITIZER_INSTR_ID_r5900_paddsw,
    RABBITIZER_INSTR_ID_r5900_psubsw,
    RABBITIZER_INSTR_ID_r5900_pextlw,
    RABBITIZER_INSTR_ID_r5900_ppacw,
    RABBITIZER_INSTR_ID_r5900_paddsh,
    RABBITIZER_INSTR_ID_r5900_psubsh,
    RABBITIZER_INSTR_ID_r5900_pextlh,
    RABBITIZER_INSTR_ID_r5900_ppach,
    RABBITIZER_INSTR_ID_r5900_paddsb,
    RABBITIZER_INSTR_ID_r5900_psubsb,
    RABBITIZER_INSTR_ID_r5900_pextlb,
    RABBITIZER_INSTR_ID_r5900_ppacb,
    RABBITIZER_INSTR_ID_r5900_pext5,
    RABBITIZER_INSTR_ID_r5900_ppac5,
    RABBITIZER_INSTR_ID_r5900_pabsw,
    RABBITIZER_INSTR_ID_r5900_pceqw,
    RABBITIZER_INSTR_ID_r5900_pminw,
    RABBITIZER_INSTR_ID_r5900_padsbh,
    RABBITIZER_INSTR_ID_r5900_pabsh,
    RABBITIZER_INSTR_ID_r5900_pceqh,
    RABBITIZER_INSTR_ID_r5900_pminh,
    RABBITIZER_INSTR_ID_r5900_pceqb,
    RABBITIZER_INSTR_ID_r5900_padduw,
    RABBITIZER_INSTR_ID_r5900_psubuw,
    RABBITIZER_INSTR_ID_r5900_pextuw,
    RABBITIZER_INSTR_ID_r5900_padduh,
    RABBITIZER_INSTR_ID_r5900_psubuh,
    RABBITIZER_INSTR_ID_r5900_pextuh,
    RABBITIZER_INSTR_ID_r5900_paddub,
    RABBITIZER_INSTR_ID_r5900_psubub,
    RABBITIZER_INSTR_ID_r5900_pextub,
    RABBITIZER_INSTR_ID_r5900_qfsrv,
    RABBITIZER_INSTR_ID_r5900_pmaddw,
    RABBITIZER_INSTR_ID_r5900_psllvw,
    RABBITIZER_INSTR_ID_r5900_psrlvw,
    RABBITIZER_INSTR_ID_r5900_pmsubw,
    RABBITIZER_INSTR_ID_r5900_pmfhi,
    RABBITIZER_INSTR_ID_r5900_pmflo,
    RABBITIZER_INSTR_ID_r5900_pinth,
    RABBITIZER_INSTR_ID_r5900_pmultw,
    RABBITIZER_INSTR_ID_r5900_pdivw,
    RABBITIZER_INSTR_ID_r5900_pcpyld,
    RABBITIZER_INSTR_ID_r5900_pmaddh,
    RABBITIZER_INSTR_ID_r5900_phmadh,
    RABBITIZER_INSTR_ID_r5900_pand,
    RABBITIZER_INSTR_ID_r5900_pxor,
    RABBITIZER_INSTR_ID_r5900_pmsubh,
    RABBITIZER_INSTR_ID_r5900_phmsbh,
    RABBITIZER_INSTR_ID_r5900_pexeh,
    RABBITIZER_INSTR_ID_r5900_prevh,
    RABBITIZER_INSTR_ID_r5900_pmulth,
    RABBITIZER_INSTR_ID_r5900_pdivbw,
    RABBITIZER_INSTR_ID_r5900_pexew,
    RABBITIZER_INSTR_ID_r5900_prot3w,
    RABBITIZER_INSTR_ID_r5900_pmadduw,
    RABBITIZER_INSTR_ID_r5900_psravw,
    RABBITIZER_INSTR_ID_r5900_pmthi,
    RABBITIZER_INSTR_ID_r5900_pmtlo,
    RABBITIZER_INSTR_ID_r5900_pinteh,
    RABBITIZER_INSTR_ID_r5900_pmultuw,
    RABBITIZER_INSTR_ID_r5900_pdivuw,
    RABBITIZER_INSTR_ID_r5900_pcpyud,
    RABBITIZER_INSTR_ID_r5900_por,
    RABBITIZER_INSTR_ID_r5900_pnor,
    RABBITIZER_INSTR_ID_r5900_pexch,
    RABBITIZER_INSTR_ID_r5900_pcpyh,
    RABBITIZER_INSTR_ID_r5900_pexcw,
    RABBITIZER_INSTR_ID_r5900_pmfhl_lw,
    RABBITIZER_INSTR_ID_r5900_pmfhl_uw,
    RABBITIZER_INSTR_ID_r5900_pmfhl_slw,
    RABBITIZER_INSTR_ID_r5900_pmfhl_lh,
    RABBITIZER_INSTR_ID_r5900_pmfhl_sh,
    RABBITIZER_INSTR_ID_r5900_pmthl_lw,
    RABBITIZER_INSTR_ID_r5900_ei,
    RABBITIZER_INSTR_ID_r5900_di,
    RABBITIZER_INSTR_ID_r5900_c1__sqrt_s,
    RABBITIZER_INSTR_ID_r5900_rsqrt_s,
    RABBITIZER_INSTR_ID_r5900_adda_s,
    RABBITIZER_INSTR_ID_r5900_suba_s,
    RABBITIZER_INSTR_ID_r5900_mula_s,
    RABBITIZER_INSTR_ID_r5900_madd_s,
    RABBITIZER_INSTR_ID_r5900_msub_s,
    RABBITIZER_INSTR_ID_r5900_madda_s,
    RABBITIZER_INSTR_ID_r5900_msuba_s,
    RABBITIZER_INSTR_ID_r5900_max_s,
    RABBITIZER_INSTR_ID_r5900_min_s,
    RABBITIZER_INSTR_ID_r5900_c_lt_s,
    RABBITIZER_INSTR_ID_r5900_c_le_s,
    RABBITIZER_INSTR_ID_r5900_qmfc2_ni,
    RABBITIZER_INSTR_ID_r5900_cfc2_ni,
    RABBITIZER_INSTR_ID_r5900_qmtc2_ni,
    RABBITIZER_INSTR_ID_r5900_ctc2_ni,
    RABBITIZER_INSTR_ID_r5900_qmfc2_i,
    RABBITIZER_INSTR_ID_r5900_cfc2_i,
    RABBITIZER_INSTR_ID_r5900_qmtc2_i,
    RABBITIZER_INSTR_ID_r5900_ctc2_i,
    RABBITIZER_INSTR_ID_r5900_bc2f,
    RABBITIZER_INSTR_ID_r5900_bc2t,
    RABBITIZER_INSTR_ID_r5900_bc2fl,
    RABBITIZER_INSTR_ID_r5900_bc2tl,
    RABBITIZER_INSTR_ID_r5900_vaddx,
    RABBITIZER_INSTR_ID_r5900_vaddy,
    RABBITIZER_INSTR_ID_r5900_vaddz,
    RABBITIZER_INSTR_ID_r5900_vaddw,
    RABBITIZER_INSTR_ID_r5900_vsubx,
    RABBITIZER_INSTR_ID_r5900_vsuby,
    RABBITIZER_INSTR_ID_r5900_vsubz,
    RABBITIZER_INSTR_ID_r5900_vsubw,
    RABBITIZER_INSTR_ID_r5900_vmaddx,
    RABBITIZER_INSTR_ID_r5900_vmaddy,
    RABBITIZER_INSTR_ID_r5900_vmaddz,
    RABBITIZER_INSTR_ID_r5900_vmaddw,
    RABBITIZER_INSTR_ID_r5900_vmsubx,
    RABBITIZER_INSTR_ID_r5900_vmsuby,
    RABBITIZER_INSTR_ID_r5900_vmsubz,
    RABBITIZER_INSTR_ID_r5900_vmsubw,
    RABBITIZER_INSTR_ID_r5900_vmaxx,
    RABBITIZER_INSTR_ID_r5900_vmaxy,
    RABBITIZER_INSTR_ID_r5900_vmaxz,
    RABBITIZER_INSTR_ID_r5900_vmaxw,
    RABBITIZER_INSTR_ID_r5900_vminix,
    RABBITIZER_INSTR_ID_r5900_vminiy,
    RABBITIZER_INSTR_ID_r5900_vminiz,
    RABBITIZER_INSTR_ID_r5900_vminiw,
    RABBITIZER_INSTR_ID_r5900_vmulx,
    RABBITIZER_INSTR_ID_r5900_vmuly,
    RABBITIZER_INSTR_ID_r5900_vmulz,
    RABBITIZER_INSTR_ID_r5900_vmulw,
    RABBITIZER_INSTR_ID_r5900_vmulq,
    RABBITIZER_INSTR_ID_r5900_vmaxi,
    RABBITIZER_INSTR_ID_r5900_vmuli,
    RABBITIZER_INSTR_ID_r5900_vminii,
    RABBITIZER_INSTR_ID_r5900_vaddq,
    RABBITIZER_INSTR_ID_r5900_vmaddq,
    RABBITIZER_INSTR_ID_r5900_vaddi,
    RABBITIZER_INSTR_ID_r5900_vmaddi,
    RABBITIZER_INSTR_ID_r5900_vsubq,
    RABBITIZER_INSTR_ID_r5900_vmsubq,
    RABBITIZER_INSTR_ID_r5900_vsubi,
    RABBITIZER_INSTR_ID_r5900_vmsubi,
    RABBITIZER_INSTR_ID_r5900_vadd,
    RABBITIZER_INSTR_ID_r5900_vmadd,
    RABBITIZER_INSTR_ID_r5900_vmul,
    RABBITIZER_INSTR_ID_r5900_vmax,
    RABBITIZER_INSTR_ID_r5900_vsub,
    RABBITIZER_INSTR_ID_r5900_vmsub,
    RABBITIZER_INSTR_ID_r5900_vopmsub,
    RABBITIZER_INSTR_ID_r5900_vmini,
    RABBITIZER_INSTR_ID_r5900_viadd,
    RABBITIZER_INSTR_ID_r5900_visub,
    RABBITIZER_INSTR_ID_r5900_viaddi,
    RABBITIZER_INSTR_ID_r5900_viand,
    RABBITIZER_INSTR_ID_r5900_vior,
    RABBITIZER_INSTR_ID_r5900_vcallms,
    RABBITIZER_INSTR_ID_r5900_vcallmsr,
    RABBITIZER_INSTR_ID_r5900_vaddax,
    RABBITIZER_INSTR_ID_r5900_vadday,
    RABBITIZER_INSTR_ID_r5900_vaddaz,
    RABBITIZER_INSTR_ID_r5900_vaddaw,
    RABBITIZER_INSTR_ID_r5900_vsubax,
    RABBITIZER_INSTR_ID_r5900_vsubay,
    RABBITIZER_INSTR_ID_r5900_vsubaz,
    RABBITIZER_INSTR_ID_r5900_vsubaw,
    RABBITIZER_INSTR_ID_r5900_vmaddax,
    RABBITIZER_INSTR_ID_r5900_vmadday,
    RABBITIZER_INSTR_ID_r5900_vmaddaz,
    RABBITIZER_INSTR_ID_r5900_vmaddaw,
    RABBITIZER_INSTR_ID_r5900_vmsubax,
    RABBITIZER_INSTR_ID_r5900_vmsubay,
    RABBITIZER_INSTR_ID_r5900_vmsubaz,
    RABBITIZER_INSTR_ID_r5900_vmsubaw,
    RABBITIZER_INSTR_ID_r5900_vitof0,
    RABBITIZER_INSTR_ID_r5900_vitof4,
    RABBITIZER_INSTR_ID_r5900_vitof12,
    RABBITIZER_INSTR_ID_r5900_vitof15,
    RABBITIZER_INSTR_ID_r5900_vftoi0,
    RABBITIZER_INSTR_ID_r5900_vftoi4,
    RABBITIZER_INSTR_ID_r5900_vftoi12,
    RABBITIZER_INSTR_ID_r5900_vftoi15,
    RABBITIZER_INSTR_ID_r5900_vmulax,
    RABBITIZER_INSTR_ID_r5900_vmulay,
    RABBITIZER_INSTR_ID_r5900_vmulaz,
    RABBITIZER_INSTR_ID_r5900_vmulaw,
    RABBITIZER_INSTR_ID_r5900_vmulaq,
    RABBITIZER_INSTR_ID_r5900_vabs,
    RABBITIZER_INSTR_ID_r5900_vmulai,
    RABBITIZER_INSTR_ID_r5900_vclipw,
    RABBITIZER_INSTR_ID_r5900_vaddaq,
    RABBITIZER_INSTR_ID_r5900_vmaddaq,
    RABBITIZER_INSTR_ID_r5900_vaddai,
    RABBITIZER_INSTR_ID_r5900_vmaddai,
    RABBITIZER_INSTR_ID_r5900_vsubaq,
    RABBITIZER_INSTR_ID_r5900_vmsubaq,
    RABBITIZER_INSTR_ID_r5900_vsubai,
    RABBITIZER_INSTR_ID_r5900_vmsubai,
    RABBITIZER_INSTR_ID_r5900_vadda,
    RABBITIZER_INSTR_ID_r5900_vmadda,
    RABBITIZER_INSTR_ID_r5900_vmula,
    RABBITIZER_INSTR_ID_r5900_vsuba,
    RABBITIZER_INSTR_ID_r5900_vmsuba,
    RABBITIZER_INSTR_ID_r5900_vopmula,
    RABBITIZER_INSTR_ID_r5900_vnop,
    RABBITIZER_INSTR_ID_r5900_vmove,
    RABBITIZER_INSTR_ID_r5900_vmr32,
    RABBITIZER_INSTR_ID_r5900_vlqi,
    RABBITIZER_INSTR_ID_r5900_vsqi,
    RABBITIZER_INSTR_ID_r5900_vlqd,
    RABBITIZER_INSTR_ID_r5900_vsqd,
    RABBITIZER_INSTR_ID_r5900_vdiv,
    RABBITIZER_INSTR_ID_r5900_vsqrt,
    RABBITIZER_INSTR_ID_r5900_vrsqrt,
    RABBITIZER_INSTR_ID_r5900_vwaitq,
    RABBITIZER_INSTR_ID_r5900_vmtir,
    RABBITIZER_INSTR_ID_r5900_vmfir,
    RABBITIZER_INSTR_ID_r5900_vrnext,
    RABBITIZER_INSTR_ID_r5900_vrget,
    RABBITIZER_INSTR_ID_r5900_vrinit,
    RABBITIZER_INSTR_ID_r5900_vrxor,
    RABBITIZER_INSTR_ID_r5900_vilwr_w,
    RABBITIZER_INSTR_ID_r5900_vilwr_z,
    RABBITIZER_INSTR_ID_r5900_vilwr_y,
    RABBITIZER_INSTR_ID_r5900_vilwr_x,
    RABBITIZER_INSTR_ID_r5900_viswr_w,
    RABBITIZER_INSTR_ID_r5900_viswr_z,
    RABBITIZER_INSTR_ID_r5900_viswr_y,
    RABBITIZER_INSTR_ID_r5900_viswr_x,
    RABBITIZER_INSTR_ID_r5900_USERDEF_00,
    RABBITIZER_INSTR_ID_r5900_USERDEF_01,
    RABBITIZER_INSTR_ID_r5900_USERDEF_02,
    RABBITIZER_INSTR_ID_r5900_USERDEF_03,
    RABBITIZER_INSTR_ID_r5900_USERDEF_04,
    RABBITIZER_INSTR_ID_r5900_USERDEF_05,
    RABBITIZER_INSTR_ID_r5900_USERDEF_06,
    RABBITIZER_INSTR_ID_r5900_USERDEF_07,
    RABBITIZER_INSTR_ID_r5900_USERDEF_08,
    RABBITIZER_INSTR_ID_r5900_USERDEF_09,
    RABBITIZER_INSTR_ID_r5900_USERDEF_10,
    RABBITIZER_INSTR_ID_r5900_USERDEF_11,
    RABBITIZER_INSTR_ID_r5900_USERDEF_12,
    RABBITIZER_INSTR_ID_r5900_USERDEF_13,
    RABBITIZER_INSTR_ID_r5900_USERDEF_14,
    RABBITIZER_INSTR_ID_r5900_USERDEF_15,
    RABBITIZER_INSTR_ID_r5900_USERDEF_16,
    RABBITIZER_INSTR_ID_r5900_USERDEF_17,
    RABBITIZER_INSTR_ID_r5900_USERDEF_18,
    RABBITIZER_INSTR_ID_r5900_USERDEF_19,
    RABBITIZER_INSTR_ID_r5900_MAX,
    RABBITIZER_INSTR_ID_ALL_LAST,
    RABBITIZER_INSTR_ID_ALL_MAX = RABBITIZER_INSTR_ID_ALL_LAST - 1
} RabbitizerInstrId;

#endif
