/* SPDX-FileCopyrightText: © 2022-2024 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef InstrCategory_enum_h_automatic
#define InstrCategory_enum_h_automatic

typedef enum RabbitizerInstrCategory {
    RABBITIZER_INSTRCAT_CPU,
    RABBITIZER_INSTRCAT_RSP,
    RABBITIZER_INSTRCAT_R3000GTE,
    RABBITIZER_INSTRCAT_R4000ALLEGREX,
    RABBITIZER_INSTRCAT_R5900,
    RABBITIZER_INSTRCAT_MAX,
} RabbitizerInstrCategory;

#endif
